@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtGui
 
 class CpStatusTip(object):
     def CpStatusTip(self, parent=None):
@@ -16,8 +16,7 @@ class CpStatusTip(object):
             self.btnResetScale : "Scale reset button",
             self.Screenshot_pb : "Screenshot of the time evolution curve (png format)",
             self.Gnuplot_pb : "Write the Gnuplot data file (dat format)",
-            self.plot : "Plot of the probes versus time (in s) - use mouse wheel to magnify, middle button to translate the curves and left button to create a rectangular selection ",
-            #self.plot : "Coordinates !",
+            self.PlotWindow : "Plot of the probes versus time (in s) - use mouse wheel to magnify, middle button to translate the curves and left button to create a rectangular selection ",
             self.Cb_Vars[0] : "Combo box to choose the physical quantity to be plotted",
             self.Cb_Vars[1] : "Combo box to choose the physical quantity to be plotted",
             self.Cb_Vars[2] : "Combo box to choose the physical quantity to be plotted",
@@ -48,6 +47,6 @@ class CpStatusTip(object):
             self.Cb_Top4 : "Combo box to choose the probe number to be drawn on graph 4 (defined in Output window)"} 
 
         for wid in self.widget:
-            wid.setStatusTip(QtGui.QApplication.translate("MainWindow", Cpdic_status[wid], None, QtGui.QApplication.UnicodeUTF8))
+            wid.setStatusTip(QtCore.QCoreApplication.translate("MainWindow", Cpdic_status[wid]))
         pass
     
