@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtGui
 
 class CpToolTip(object):
     def CpToolTip(self, parent=None):
-        
+
         #Tooltip dictionnary
         Cpdic_tool={
             #calculation_progress
@@ -16,7 +16,7 @@ class CpToolTip(object):
             self.btnResetScale : "Scale reset button",
             self.Screenshot_pb : "Screenshot of the time evolution curve (png format)",
             self.Gnuplot_pb : "Write the Gnuplot data file (dat format)",
-            self.plot : "Plot of the probes versus time (in s) - use mouse wheel to magnify and left button to translate the curves",
+            self.PlotWindow : "Plot of the probes versus time (in s) - use mouse wheel to magnify and left button to translate the curves",
             self.Cb_Vars[0] : "Combo box to choose the physical quantity to be plotted",
             self.Cb_Vars[1] : "Combo box to choose the physical quantity to be plotted",
             self.Cb_Vars[2] : "Combo box to choose the physical quantity to be plotted",
@@ -42,12 +42,12 @@ class CpToolTip(object):
             self.cbStyle_tab2 : "Line style of Graph 2",
             self.cbStyle_tab3 : "Line style of Graph 3",
             self.cbStyle_tab4 : "Line style of Graph 4",
-            self.Cb_Top2 : "Combo box to choose the probe number to be drawn on graph 2 (defined in Output window)", 
+            self.Cb_Top2 : "Combo box to choose the probe number to be drawn on graph 2 (defined in Output window)",
             self.Cb_Top3 : "Combo box to choose the probe number to be drawn on graph 3 (defined in Output window)",
             self.Cb_Top4 : "Combo box to choose the probe number to be drawn on graph 4 (defined in Output window)"
         }
-        
+
         for wid in self.widget:
             #if wid != self.plot:
-            wid.setToolTip(QtGui.QApplication.translate("MainWindow", Cpdic_tool[wid], None, QtGui.QApplication.UnicodeUTF8))
+            wid.setToolTip(QtCore.QCoreApplication.translate("MainWindow", Cpdic_tool[wid]))
         pass
