@@ -2,12 +2,12 @@
 
 import os, sys, string, subprocess, gc
 from time import sleep
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtGui
 from syrthesIHMContext import syrthesIHMContext
 
 class CpWhatsThis(object):
     def CpWhatsThis(self, parent=None):
-        
+
         # What's this dictionnary
         Cpdic_what={
             #calculation_progress
@@ -19,7 +19,7 @@ class CpWhatsThis(object):
             self.btnResetScale : "btnResetScale",
             self.Screenshot_pb : "Screenshot_pb",
             self.Gnuplot_pb : "Gnuplot_pb",
-            self.plot : "plot",
+            self.PlotWindow : "plot",
             self.Cb_Vars[0] : "Cb_Vars0",
             self.Cb_Vars[1] : "Cb_Vars1",
             self.Cb_Vars[2] : "Cb_Vars2",
@@ -44,24 +44,26 @@ class CpWhatsThis(object):
             self.cbStyle_tab2 : "cbStyle_tab2",
             self.cbStyle_tab3 : "cbStyle_tab3",
             self.cbStyle_tab4 : "cbStyle_tab4",
-            self.Cb_Top2 : "Cb_Top2", 
+            self.Cb_Top2 : "Cb_Top2",
             self.Cb_Top3 : "Cb_Top3",
             self.Cb_Top4 : "Cb_Top4"
         }
-        
-        path = syrthesIHMContext.getExeAbsDirPath()
+
+        #MPpath = syrthesIHMContext.getExeAbsDirPath()
+        path = os.getenv('SYRTHES4_HOME')+ os.sep + "lib"+ os.sep + "syrthesGui"
         for wid in self.widget:
-            wid.setWhatsThis(QtGui.QApplication.translate("MainWindow", self.funcReadWhat(Cpdic_what[wid]), None, QtGui.QApplication.UnicodeUTF8))
+            wid.setWhatsThis(QtCore.QCoreApplication.translate("MainWindow", self.funcReadWhat(Cpdic_what[wid])))
         pass
-    
+
     def funcReadWhat(self, nomfic):
-        path = syrthesIHMContext.getExeAbsDirPath()
+        #MPpath = syrthesIHMContext.getExeAbsDirPath()
+        path = os.getenv('SYRTHES4_HOME')+ os.sep + "lib"+ os.sep + "syrthesGui"
         self.ficwhat=open(path + os.sep + "ficwhatsthis" + os.sep + nomfic + ".html", "r")
         self.linewhat=self.ficwhat.readline()
         resultat = ""
         while self.linewhat:
             resultat += self.linewhat
             self.linewhat=self.ficwhat.readline()
-        
+
         resultat = resultat.replace("ficwhatsthis/images/", path + os.sep + "ficwhatsthis" + os.sep + "images" + os.sep)
         return resultat
