@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 import os, sys, string, subprocess, gc
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtGui
 from time import sleep
 from syrthesIHMContext import syrthesIHMContext
 
 def WhatsThis(self, parent=None):
-    
+
 #WhatsThis dictionnary
     dic_what={#Mainwindow
                 self.action_New_file : "action_New_file", #action de la barre d'outil:action nouveau fichier
@@ -43,14 +43,14 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Control_form.Vap_Sp_le : 'Vap_Sp_le', #champ éditable de la précision du solver
                 self.syrthesIHMCollector.Control_form.Vap_Mn_le : 'Vap_Mn_le', #champ éditable du nombre maximum d'itération
                 self.syrthesIHMCollector.Control_form.Ap_Sp_le : 'Ap_Sp_le', #champ éditable de la précision du solver
-                self.syrthesIHMCollector.Control_form.Ap_Mn_le : 'Ap_Mn_le', #champ éditable du nombre maximum d'itération                   
+                self.syrthesIHMCollector.Control_form.Ap_Mn_le : 'Ap_Mn_le', #champ éditable du nombre maximum d'itération
                 #Boundary_conditions_form
                 self.syrthesIHMCollector.Boundary_conditions_cond_form.Heat_ex_table : "Heat_ex_table",#tableau de l'échange de chaleur
                 self.syrthesIHMCollector.Boundary_conditions_cond_form.Cont_res_table : "Cont_res_table",#tableau de la réseistance de contact
                 self.syrthesIHMCollector.Boundary_conditions_cond_form.Flux_cond_table : "Flux_cond_table",#tableau de la condition du flux
                 self.syrthesIHMCollector.Boundary_conditions_cond_form.Diric_cond_table : "Diric_cond_table",#tableau de la condition Dirichlet
                 self.syrthesIHMCollector.Boundary_conditions_cond_form.Inf_rad_table : "Inf_rad_table",#tableau de la radiation infinit
-                #Physical_properties_2D_form 
+                #Physical_properties_2D_form
 ##                    self.Dens_2D_table : "31",#tableau de la densité
 ##                    self.Heat_cap_2D_table : "32",#tableau de la capacité calorifique
                 self.syrthesIHMCollector.Physical_prop_2D_form.Iso_cond_2D_table : "Iso_cond_2D_table",#tableau de la conductivité isotropic
@@ -153,7 +153,7 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Solar_aspect_form.Sa_Sht_table : "Sa_Sht_table",#tableau de l'équilibrage de la chaleur solaire
                 self.syrthesIHMCollector.Solar_aspect_form.Sa_Hm_table : "Sa_Hm_table",#tableau de la modélisation de l'horizon
                 self.syrthesIHMCollector.Solar_aspect_form.Sa_Sm_table :"Sa_Sm_table",#tableau de la modélisation de l'ombrage
-                self.syrthesIHMCollector.Solar_aspect_form.Csm_cmb : "Csm_cmb", 
+                self.syrthesIHMCollector.Solar_aspect_form.Csm_cmb : "Csm_cmb",
                 self.syrthesIHMCollector.Solar_aspect_form.lineEdit : "lineEdit",
                 #Humidity_model_form
                 self.syrthesIHMCollector.Home_form.Hm_cmb : "Hm_cmb",#combobox du modèle d'humidité
@@ -201,21 +201,21 @@ def WhatsThis(self, parent=None):
 
                 self.syrthesIHMCollector.Advanced_mode_form.Advanced_cmd_table : "Advanced_cmd_table", # mode avancé
                 # Output
-                self.syrthesIHMCollector.Output_2D_form.Tf_cb_2D_Op : "Tf_cb_2D_Op", 
-                self.syrthesIHMCollector.Output_2D_form.Cb_2D_Op : "Cb_2D_Op", 
+                self.syrthesIHMCollector.Output_2D_form.Tf_cb_2D_Op : "Tf_cb_2D_Op",
+                self.syrthesIHMCollector.Output_2D_form.Cb_2D_Op : "Cb_2D_Op",
                 self.syrthesIHMCollector.Output_2D_form.Cb2_2D_Op : "Cb2_2D_Op",
-                self.syrthesIHMCollector.Output_2D_form.Le_2D_Op : "Le_2D_Op", 
-                self.syrthesIHMCollector.Output_2D_form.Le2_2D_Op : "Le2_2D_Op", 
-                self.syrthesIHMCollector.Output_2D_form.Op_Dc_2D_table : "Op_Dc_2D_table", 
-                self.syrthesIHMCollector.Output_2D_form.Op_Sb_2D_table : "Op_Sb_2D_table", 
+                self.syrthesIHMCollector.Output_2D_form.Le_2D_Op : "Le_2D_Op",
+                self.syrthesIHMCollector.Output_2D_form.Le2_2D_Op : "Le2_2D_Op",
+                self.syrthesIHMCollector.Output_2D_form.Op_Dc_2D_table : "Op_Dc_2D_table",
+                self.syrthesIHMCollector.Output_2D_form.Op_Sb_2D_table : "Op_Sb_2D_table",
                 self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table : "Op_Vb_2D_table",
-                self.syrthesIHMCollector.Output_3D_form.Tf_cb_3D_Op : "Tf_cb_3D_Op", 
-                self.syrthesIHMCollector.Output_3D_form.Cb_3D_Op : "Cb_3D_Op", 
+                self.syrthesIHMCollector.Output_3D_form.Tf_cb_3D_Op : "Tf_cb_3D_Op",
+                self.syrthesIHMCollector.Output_3D_form.Cb_3D_Op : "Cb_3D_Op",
                 self.syrthesIHMCollector.Output_3D_form.Cb2_3D_Op : "Cb2_3D_Op",
-                self.syrthesIHMCollector.Output_3D_form.Le_3D_Op : "Le_3D_Op", 
-                self.syrthesIHMCollector.Output_3D_form.Le2_3D_Op : "Le2_3D_Op", 
-                self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table : "Op_Dc_3D_table", 
-                self.syrthesIHMCollector.Output_3D_form.Op_Sb_3D_table : "Op_Sb_3D_table", 
+                self.syrthesIHMCollector.Output_3D_form.Le_3D_Op : "Le_3D_Op",
+                self.syrthesIHMCollector.Output_3D_form.Le2_3D_Op : "Le2_3D_Op",
+                self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table : "Op_Dc_3D_table",
+                self.syrthesIHMCollector.Output_3D_form.Op_Sb_3D_table : "Op_Sb_3D_table",
                 self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table : "Op_Vb_3D_table",
                 self.syrthesIHMCollector.Output_3D_form.Hf_cb_3D_Op : "Hf_cb_3D_Op",
                 self.syrthesIHMCollector.Output_3D_form.Mt_cb_3D_Op : "Mt_cb_3D_Op",
@@ -243,7 +243,7 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table : "Singular_head_fluid1d_table", # tableau perte de charge fluid1d singuliere
                 self.syrthesIHMCollector.Control_fluid1d_form.Cb_solid_Ts_fluid1d : "Cb_solid_Ts_fluid1d", #checkbox pour indiquer que le pas de temps FLUIDE 1D est egal au pas de temps solide
                 self.syrthesIHMCollector.Control_fluid1d_form.Le_const_Ts_fluid1d : "Le_const_Ts_fluid1d", #champ éditable du pas de temps FLUIDE 1D
-                
+
                 # DH (BT)
                 self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl : "Bcfluid1d_Q_table_cl", #champ d'édition de la closed loop
                 self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl : "Bcfluid1d_Q_table_th_cl", #champ d'édition de la thermal closed loop
@@ -258,22 +258,25 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table : "Prop_fluid0d_table",
                 self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table : "Geom_fluid0d_table", # tableau pour la geometrie pour fluid0d
                 self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table : "Volumetric_conditions_fluid0d_table" # tableau pour la conditions volumetriques pour fluid0d
-                } 
+                }
 
-    for wid in self.widget:      
-        wid.setWhatsThis(QtGui.QApplication.translate("MainWindow", self.funcReadWhat(dic_what[wid]), None, QtGui.QApplication.UnicodeUTF8))
+    for wid in self.widget:
+        wid.setWhatsThis(QtCore.QCoreApplication.translate("MainWindow", self.funcReadWhat(dic_what[wid])))
     pass
     #self.syrthesIHMCollector.User_C_function_form.Cfunc_but.setWhatsThis(QtGui.QApplication.translate("MainWindow", self.funcReadWhat(dic_what[self.syrthesIHMCollector.User_C_function_form.Cfunc_but]), None, QtGui.QApplication.UnicodeUTF8))
-    
+
 def funcReadWhat(self, nomfic):
-    path = syrthesIHMContext.getExeAbsDirPath()
+    #MPpath = syrthesIHMContext.getExeAbsDirPath()
+    path = os.getenv('SYRTHES4_HOME')+ os.sep + "lib"+ os.sep + "syrthesGui"
+    name = path + os.sep + "ficwhatsthis" + os.sep + nomfic + ".html"
+#MP Python3    self.ficwhat=open(name, "r", -1, None, "ignore")
     self.ficwhat=open(path + os.sep + "ficwhatsthis" + os.sep + nomfic + ".html", "r")
     self.linewhat=self.ficwhat.readline()
     resultat = ""
     while self.linewhat:
         resultat += self.linewhat
         self.linewhat=self.ficwhat.readline()
-    
+
     resultat = resultat.replace("ficwhatsthis/images/", path + os.sep + "ficwhatsthis" + os.sep + "images" + os.sep)
     return resultat
 
@@ -284,7 +287,7 @@ def find_names(self, obj):
     result = []
     for referrer in gc.get_referrers(obj):
         if isinstance(referrer, dict):
-            for k, v in referrer.iteritems():
+            for k, v in list(referrer.items()):
                 if v is obj:
                     result.append(k)
     return result
