@@ -1,10 +1,10 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 # Pour l'IHM Syrthes, remplacement de la chaine de carcateres VERSION_SYRTHES par la version de Syrthes
 # Le ./version_syrthes/version_syrthes doit contenir la version de Syrthes
 
 import os
+import sys
 
 def main():
 
@@ -13,7 +13,7 @@ def main():
    fich_version  = os.path.join('.', 'version_syrthes', 'version_syrthes')
    f = open(fich_version,"r")
    flines = f.read()
-   list_lines = flines.split("\n") 
+   list_lines = flines.split("\n")
    version_syrthes_value = list_lines[0]
    f.close()
    # recherche dans les repertoires install, install/22x22, install/ficwhatsthis
@@ -29,9 +29,16 @@ def main():
          if filename.endswith(".html") or filename.endswith(".py") or filename=="license"  :
             filename_l = os.path.join(directory,filename)
             if os.path.isfile(filename_l):
-               modif=file(filename_l,"r").read().replace("VERSION_SYRTHES",version_syrthes_value)
-               file(filename_l,"w").write(modif)
-
+               if sys.version_info[0] < 3:
+                  modif=file(filename_l,"r").read().replace("VERSION_SYRTHES",version_syrthes_value)
+                  file(filename_l,"w").write(modif)
+               else:
+                  with open(filename_l,"r",encoding="utf8", errors='ignore') as f:
+                     modif=f.read().replace("VERSION_SYRTHES",version_syrthes_value)
+                     f.close()
+                  with open(filename_l,"w",encoding="utf8", errors='ignore') as f:
+                     f.write(modif)
+                     f.close()
 
 if __name__ == '__main__':
     main()
