@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #-----------------------------------------------------------------------
 #
@@ -34,13 +33,13 @@
 
 #-------------------------------------------------------------------------------
 # Library modules import
-# 
-#-------------------------------------------------------------------------------
-import sys
 #
-if sys.version_info[:2] < (2,3):
-    sys.stderr.write("This script needs Python 2.3 at least\n")
-    
+#-------------------------------------------------------------------------------
+
+from __future__ import print_function  # for Python 2
+
+import sys
+
 import os, re, os.path, shutil
 import time, getpass
 #
@@ -64,19 +63,19 @@ def main():
 #-------------------------------------------------------------------------------
 # Class definition Setupmakefilein
 #
-# 
+#
 #-------------------------------------------------------------------------------
 class Setupmakefilein(object):
 
-    #----------------------------------------------------------------------------    
-    #  Fonction configuration_make 
-    #  Adjust libraries location and environment variables 
+    #----------------------------------------------------------------------------
+    #  Fonction configuration_make
+    #  Adjust libraries location and environment variables
     #----------------------------------------------------------------------------
     def configuration_make(self, Setupmakefilein, my_arch = None):
         #
         # Makefile.in file update
         #
-	makefileinFile = file('Makefile.in', mode='w')
+        makefileinFile = open('Makefile.in', mode='w')
 
         makefileinFile.write("""SHELL = /bin/sh
 # ******************************************************
@@ -84,8 +83,8 @@ class Setupmakefilein(object):
 #      Initialisation
 # ******************************************************
 # ******************************************************
-# pour appeler le makefile qui va bien 
-#(les options se cumulent quand c'est possible) 
+# pour appeler le makefile qui va bien
+#(les options se cumulent quand c'est possible)
 # make                --> version MPI, sans BLAS, sans CFD  avec DEBUG
 # make MPI=no        --> version sequentielle sans MPI
 # make BLAS=yes       --> version avec les BLAS
@@ -109,61 +108,61 @@ PART_METIS=no
 PART_SCOTCH=no
 
 """)
-        if self.dicolib['med'].has_key('PATH'):
+        if 'PATH' in self.dicolib['med']:
             makefileinFile.write("MED=yes\n")
         else :
             makefileinFile.write("MED=no\n")
 
-        if self.dicolib['mpi'].has_key('PATH'):
+        if 'PATH' in self.dicolib['mpi']:
             makefileinFile.write("MPI=yes\n")
         else :
             makefileinFile.write("MPI=no\n")
-	    
-        if self.dicolib['metis'].has_key('PATH'):
+
+        if 'PATH' in self.dicolib['metis']:
             makefileinFile.write("PART_METIS=yes\n")
         else :
-            makefileinFile.write("PART_METIS=no\n")	    
-	    
-        if self.dicolib['scotch'].has_key('PATH'):
+            makefileinFile.write("PART_METIS=no\n")
+
+        if 'PATH' in self.dicolib['scotch']:
             makefileinFile.write("PART_SCOTCH=yes\n")
         else :
-            makefileinFile.write("PART_SCOTCH=no\n")	    
-	    
-        if self.dicospeci['specific_inc'].has_key('PATH'):
+            makefileinFile.write("PART_SCOTCH=no\n")
+
+        if 'PATH' in self.dicospeci['specific_inc']:
             makefileinFile.write("INC += "+self.dicospeci['specific_inc']['PATH']+"\n")
         else :
             makefileinFile.write("INC=\n")
-	      
-        if self.dicospeci['specific_lib'].has_key('PATH'):
+
+        if 'PATH' in self.dicospeci['specific_lib']:
             makefileinFile.write("LIB += "+self.dicospeci['specific_lib']['PATH']+"\n")
         else :
             makefileinFile.write("LIB=\n")
 
-        if self.dicospeci['specific_debug'].has_key('PATH'):
+        if 'PATH' in self.dicospeci['specific_debug']:
             makefileinFile.write("DEBUG=yes\n")
             makefileinFile.write("COPTIM= "+self.dicospeci['specific_debug']['PATH']+"\n")
         else:
             makefileinFile.write("COPTIM= -O3\n")
 
         makefileinFile.write("# Sources and build directories\n")
-        makefileinFile.write("DIR_SYRTHES=%s"%self.syrthesDir+"\n") 
-        makefileinFile.write("BUILD_SYRTHES=%s"%self.syrthesDir+"/arch/"+self.arch+"\n") 
+        makefileinFile.write("DIR_SYRTHES=%s"%self.syrthesDir+"\n")
+        makefileinFile.write("BUILD_SYRTHES=%s"%self.syrthesDir+"/arch/"+self.arch+"\n")
 
         makefileinFile.write("""
 #-----------------
 # Building options
 #-----------------
 
-CFLAG = -D _FILE_OFFSET_BITS=64
-LDFLAG= -D _FILE_OFFSET_BITS=64
+CFLAG = -D _FILE_OFFSET_BITS=64 $(CFLAGS)
+LDFLAG= -D _FILE_OFFSET_BITS=64 $(LDFLAGS)
 
 ifeq ($(MPI),yes)
-	CFLAG  += -D_SYRTHES_MPI_
-	LDFLAG += -D_SYRTHES_MPI_
+        CFLAG  += -D_SYRTHES_MPI_
+        LDFLAG += -D_SYRTHES_MPI_
 endif
 
 ifeq ($(BLAS),yes)
-	CFLAG += -D_SYRTHES_BLAS_
+        CFLAG += -D_SYRTHES_BLAS_
 endif
 
 ifeq ($(CFD),yes)
@@ -171,13 +170,13 @@ ifeq ($(CFD),yes)
 endif
 
 ifeq ($(PROF),yes)
-	COPTIM = -pg
+        COPTIM = -pg
 endif
 
 """)
-        if self.dicospeci['specific_option'].has_key('PATH'):
+        if 'PATH' in self.dicospeci['specific_option']:
             makefileinFile.write("CFLAG += "+self.dicospeci['specific_option']['PATH']+"\n")
-            
+
         makefileinFile.write("""
 
 #-----------------------------------
@@ -195,21 +194,21 @@ NAME_SYRTHES2MED=syrthes4med30
 NAMELIB = libsyrthes_mpi.a
 
 ifeq ($(MPI),no)
-	NAMELIB = libsyrthes_seq.a
+        NAMELIB = libsyrthes_seq.a
 endif
 
 ifeq ($(CFD),yes)
-	NAMELIB = libsyrthes_cfd.a
+        NAMELIB = libsyrthes_cfd.a
 endif
 
 ifeq ($(DEBUG),yes)
-	NAMELIB = libsyrthes_mpi.a
-	ifeq ($(MPI),no)
-		NAMELIB = libsyrthes_seq.a
-	endif
-	ifeq ($(CFD),yes)
-		NAMELIB = libsyrthes_cfd.a
-	endif
+        NAMELIB = libsyrthes_mpi.a
+        ifeq ($(MPI),no)
+                NAMELIB = libsyrthes_seq.a
+        endif
+        ifeq ($(CFD),yes)
+                NAMELIB = libsyrthes_cfd.a
+        endif
 endif
 
 LIB_SYRTHES = $(NAMELIB)
@@ -224,44 +223,52 @@ LIB_SYRTHES = $(NAMELIB)
 """)
 
 
-                
-##  Compiler       
+
+##  Compiler
         makefileinFile.write("# Compiler path for gcc\n")
         makefileinFile.write("FRONT_CC="+self.comp+"\n")
 
+        p_mpicc = None
         if self.dicolib['mpi']['USE'].upper()=='YES':
             makefileinFile.write("# Compiler path for mpicc\n")
-            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/"+self.wrapperc+"\n"+"\n")
+            for s in ('/', '/bin/', '/bin64/'):
+                p1 = self.dicolib['mpi']['PATH'] + s + self.wrapperc
+                if os.path.isfile(p1):
+                    p_mpicc = p1
+                    break
+
+        if p_mpicc:
+            makefileinFile.write("CC="+p_mpicc+"\n")
         else:
             makefileinFile.write("CC="+self.comp+"\n")
 
-##  Compiler  CC whith out mpi    
+##  Compiler  CC whith out mpi
         makefileinFile.write("ifeq ($(MPI),no)\n")
         makefileinFile.write("        CC="+self.comp+"\n")
         makefileinFile.write("endif\n"+"\n")
 
 ##  Library
-        if  self.dicolib['metis'].has_key('PATH'):
+        if  'PATH' in self.dicolib['metis']:
              makefileinFile.write("DIR_METIS="+self.dicolib['metis']['PATH']+"\n")
-        
-        if  self.dicolib['scotch'].has_key('PATH'):
+
+        if  'PATH' in self.dicolib['scotch']:
              makefileinFile.write("DIR_SCOTCH="+self.dicolib['scotch']['PATH']+"\n")
-        
-        if  self.dicolib['med'].has_key('PATH'):
+
+        if  'PATH' in self.dicolib['med']:
              makefileinFile.write("DIR_MED="+self.dicolib['med']['PATH']+"\n")
-        
-	if  self.dicolib['hdf5'].has_key('PATH'):
+
+        if  'PATH' in self.dicolib['hdf5']:
              makefileinFile.write("DIR_HDF5="+self.dicolib['hdf5']['PATH']+"\n")
-	
-	makefileinFile.write("\nifeq ($(CFD),yes)\n")
-	if  self.dicolib['ple'].has_key('PATH'):
+
+        makefileinFile.write("\nifeq ($(CFD),yes)\n")
+        if 'PATH' in self.dicolib['ple']:
              makefileinFile.write("       DIR_PLE="+self.dicolib['ple']['PATH']+"\n")
-       	makefileinFile.write("endif\n")
+        makefileinFile.write("endif\n")
 
         makefileinFile.write("\nifeq ($(BLAS),yes)\n")
-	if  self.dicolib['blas'].has_key('PATH'):
+        if  'PATH' in self.dicolib['blas']:
              makefileinFile.write("       DIR_BLAS="+self.dicolib['blas']['PATH']+"\n")
-	makefileinFile.write("endif\n"+"\n")
+        makefileinFile.write("endif\n"+"\n")
 
 
         makefileinFile.write("""
@@ -312,27 +319,26 @@ INC_MED= -I$(DIR_MED)/include -I$(DIR_HDF5)/include
 # ensight
 LIBENSIGHT=-lm -lz -lpthread
 
-ifeq ($(CFD),yes)   
+ifeq ($(CFD),yes)
         INC += -I$(DIR_PLE)/include
         INC += -I$(DIR_SYRTHES)/src/syrthes-kernel/include
         LIB_PLE = -L$(DIR_PLE)/lib -lple -Wl,-rpath -Wl,$(DIR_PLE)/lib
 endif
 
 ifeq ($(BLAS),yes)
-	LDFLAG += -lcblas -latlas 
-	INC += -I$(DIR_BLAS)/??? isa
+        LDFLAG += -lcblas -latlas
+        INC += -I$(DIR_BLAS)/??? isa
 endif
 """)
 
         # If metis or scotch are used
         # ---------------------------
-        if  self.dicolib['metis'].has_key('PATH'):
-            
+        if  'PATH' in self.dicolib['metis']:
+
             makefileinFile.write("LIBMETIS=-L $(DIR_METIS)/lib -lmetis\n")
             makefileinFile.write("INC_METIS=-I$(DIR_METIS)/include\n")
 
-        if  self.dicolib['scotch'].has_key('PATH'):
-            
+        if  'PATH' in self.dicolib['scotch']:
             makefileinFile.write("LIBSCOTCH=-L $(DIR_SCOTCH)/lib -lscotch -L $(DIR_SCOTCH)/lib -lscotcherr\n")
             makefileinFile.write("INC_SCOTCH=-I$(DIR_SCOTCH)/include\n")
 
@@ -345,7 +351,7 @@ endif
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 
-	makefileinFile = file('Makefile2.in', mode='w')
+        makefileinFile = open('Makefile2.in', mode='w')
 
         makefileinFile.write("""SHELL = /bin/sh
 # ******************************************************
@@ -353,8 +359,8 @@ endif
 #      Initialisation
 # ******************************************************
 # ******************************************************
-# pour appeler le makefile qui va bien 
-#(les options se cumulent quand c'est possible) 
+# pour appeler le makefile qui va bien
+#(les options se cumulent quand c'est possible)
 # make                --> version MPI, sans BLAS, sans CFD  avec DEBUG
 # make MPI=no        --> version sequentielle sans MPI
 # make BLAS=yes       --> version avec les BLAS
@@ -377,37 +383,37 @@ PROF=no
 PART_METIS=no
 PART_SCOTCH=no
 """)
-        if self.dicolib['med'].has_key('PATH'):
+        if 'PATH' in self.dicolib['med']:
               makefileinFile.write("MED=yes\n")
         else :
               makefileinFile.write("MED=no\n")
 
-        if self.dicolib['mpi'].has_key('PATH'):
+        if 'PATH' in self.dicolib['mpi']:
               makefileinFile.write("MPI=yes\n")
         else :
               makefileinFile.write("MPI=no\n")
-	    
-        if self.dicolib['metis'].has_key('PATH'):
+
+        if 'PATH' in self.dicolib['metis']:
             makefileinFile.write("PART_METIS=yes\n")
         else :
-            makefileinFile.write("PART_METIS=no\n")	    
-	    
-        if self.dicolib['scotch'].has_key('PATH'):
+            makefileinFile.write("PART_METIS=no\n")
+
+        if 'PATH' in self.dicolib['scotch']:
             makefileinFile.write("PART_SCOTCH=yes\n")
         else :
-            makefileinFile.write("PART_SCOTCH=no\n")	    
-      
-        if self.dicospeci['specific_inc'].has_key('PATH'):
+            makefileinFile.write("PART_SCOTCH=no\n")
+
+        if 'PATH' in self.dicospeci['specific_inc']:
               makefileinFile.write("INC += -I"+self.dicospeci['specific_inc']['PATH']+"\n")
         else :
               makefileinFile.write("INC=\n")
-	      
-        if self.dicospeci['specific_lib'].has_key('PATH'):
+
+        if 'PATH' in self.dicospeci['specific_lib']:
               makefileinFile.write("LIB += -L"+self.dicospeci['specific_lib']['PATH']+"\n")
         else :
               makefileinFile.write("LIB=\n")
 
-        if self.dicospeci['specific_debug'].has_key('PATH'):
+        if 'PATH' in self.dicospeci['specific_debug']:
             makefileinFile.write("DEBUG=yes\n")
             makefileinFile.write("COPTIM= "+self.dicospeci['specific_debug']['PATH']+"\n")
         else:
@@ -421,16 +427,16 @@ PART_SCOTCH=no
 # Building options
 #-----------------
 
-CFLAG = -D _FILE_OFFSET_BITS=64
-LDFLAG= -D _FILE_OFFSET_BITS=64
+CFLAG = -D _FILE_OFFSET_BITS=64 $(CFLAGS)
+LDFLAG= -D _FILE_OFFSET_BITS=64 $(LDFLAGS)
 
 ifeq ($(MPI),yes)
-	CFLAG  += -D_SYRTHES_MPI_
-	LDFLAG += -D_SYRTHES_MPI_
+        CFLAG  += -D_SYRTHES_MPI_
+        LDFLAG += -D_SYRTHES_MPI_
 endif
 
 ifeq ($(BLAS),yes)
-	CFLAG += -D_SYRTHES_BLAS_
+        CFLAG += -D_SYRTHES_BLAS_
 endif
 
 ifeq ($(CFD),yes)
@@ -438,14 +444,14 @@ ifeq ($(CFD),yes)
 endif
 
 ifeq ($(PROF),yes)
-	COPTIM = -pg
+        COPTIM = -pg
 endif
 
 
 """)
-        if self.dicospeci['specific_option'].has_key('PATH'):
+        if 'PATH' in self.dicospeci['specific_option']:
             makefileinFile.write("CFLAG += "+self.dicospeci['specific_option']['PATH']+"\n")
-            
+
         makefileinFile.write("""
 
 
@@ -456,21 +462,21 @@ endif
 NAMELIB = libsyrthes_mpi.a
 
 ifeq ($(MPI),no)
-	NAMELIB = libsyrthes_seq.a
+        NAMELIB = libsyrthes_seq.a
 endif
 
 ifeq ($(CFD),yes)
-	NAMELIB = libsyrthes_cfd.a
+        NAMELIB = libsyrthes_cfd.a
 endif
 
 ifeq ($(DEBUG),yes)
-	NAMELIB = libsyrthes_mpi.a
-	ifeq ($(MPI),no)
-		NAMELIB = libsyrthes_seq.a
-	endif
-	ifeq ($(CFD),yes)
-		NAMELIB = libsyrthes_cfd.a
-	endif
+        NAMELIB = libsyrthes_mpi.a
+        ifeq ($(MPI),no)
+                NAMELIB = libsyrthes_seq.a
+        endif
+        ifeq ($(CFD),yes)
+                NAMELIB = libsyrthes_cfd.a
+        endif
 endif
 
 LIB_SYRTHES = $(NAMELIB)
@@ -485,32 +491,40 @@ LIB_SYRTHES = $(NAMELIB)
 """)
 
 
-                
-##  Compiler       
+##  Compiler
         makefileinFile.write("# Compiler path for gcc\n")
         makefileinFile.write("FRONT_CC="+self.comp+"\n")
 
+        p_mpicc = None
         if self.dicolib['mpi']['USE'].upper()=='YES':
             makefileinFile.write("# Compiler path for mpicc\n")
-            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/"+self.wrapperc+"\n"+"\n")
+            for s in ('/', '/bin/', '/bin64/'):
+                p1 = self.dicolib['mpi']['PATH'] + s + self.wrapperc
+                if os.path.isfile(p1):
+                    p_mpicc = p1
+                    break
+
+        if p_mpicc:
+            makefileinFile.write("# Compiler path for mpicc\n")
+            makefileinFile.write("CC="+p_mpicc+"\n")
         else:
             makefileinFile.write("CC="+self.comp+"\n")
-            
-##  Compiler  CC whith out mpi    
+
+##  Compiler  CC whith out mpi
         makefileinFile.write("ifeq ($(MPI),no)\n")
         makefileinFile.write("        CC="+self.comp+"\n")
-	makefileinFile.write("endif\n"+"\n")
+        makefileinFile.write("endif\n"+"\n")
 
 ##  Library
-	makefileinFile.write("\nifeq ($(CFD),yes)\n")
-	if  self.dicolib['ple'].has_key('PATH'):
+        makefileinFile.write("\nifeq ($(CFD),yes)\n")
+        if  'PATH' in self.dicolib['ple']:
              makefileinFile.write("       DIR_PLE="+self.dicolib['ple']['PATH']+"\n")
-       	makefileinFile.write("endif\n")
+        makefileinFile.write("endif\n")
 
         makefileinFile.write("\nifeq ($(BLAS),yes)\n")
-	if  self.dicolib['blas'].has_key('PATH'):
+        if  'PATH' in self.dicolib['blas']:
              makefileinFile.write("       DIR_BLAS="+self.dicolib['blas']['PATH']+"\n")
-	makefileinFile.write("endif\n"+"\n")
+        makefileinFile.write("endif\n"+"\n")
 
 
         makefileinFile.write("""
@@ -547,33 +561,24 @@ INC_SYRTHES_LIBMAT    = -I$(BUILD_SYRTHES)/lib_material_syrthes
 INC_SYRTHES= -I$(BUILD_SYRTHES)/include
 LIB_SYRTHES=$(DIRLIB_KERNEL)/$(NAMELIB)
 
-ifeq ($(CFD),yes)   
+ifeq ($(CFD),yes)
         INC += -I$(DIR_PLE)/include
         INC += -I$(BUILD_SYRTHES)/include
         LIB_PLE = -L$(DIR_PLE)/lib -lple -Wl,-rpath -Wl,$(DIR_PLE)/lib
 endif
 
 ifeq ($(BLAS),yes)
-	LDFLAG += -lcblas -latlas 
-	INC += -I$(DIR_BLAS)/??? isa
+        LDFLAG += -lcblas -latlas
+        INC += -I$(DIR_BLAS)/??? isa
 endif
 """)
         makefileinFile.close()
 
 
-
-
-
-
-
-
-
-
-
 #-------------------------------------------------------------------------------
-# 
+#
 # Progam principal
-# 
+#
 #
 #
 #-------------------------------------------------------------------------------
