@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -35,9 +35,9 @@
 #include "syr_tree.h"
 #include "syr_hmt_bd.h"
 
+#include "syr_cfd.h"
 #ifdef _SYRTHES_CFD_
 #include "syr_cfd_coupling.h"
-#include "syr_cfd.h"
 #endif
 
 
@@ -86,8 +86,10 @@ void besoin2d(int**,int**,int*,int,int**,double***,int**,double,double);
 void bilsolaire(struct Maillage,struct Soleil,struct Bilan,struct Bande,double*,double);
 void bilsurf(struct Maillage,struct MaillageCL,
 	     struct Climcfd,struct Clim,struct Clim,struct Contact,struct Couple,
-	     struct Clim,double*,struct Bilan,double);
-void bilvol(struct Maillage,struct Climcfd,struct Cvol,double*,struct Bilan,double);
+	     struct Clim,struct HmtClimhhh, struct ConstPhyhmt,
+	     struct Variable,struct Bilan,double);
+void bilvol(struct Maillage,struct Climcfd,struct Cvol,struct Variable,struct Bilan,double,
+	    struct Humid,double **,struct ConstPhyhmt,struct ConstMateriaux*);
 void boite(int,double**,double[]);
 void boite2(int,int,double**,int,double**,double[]);
 void box_2d(int,double**);
@@ -220,15 +222,22 @@ void dupliq_maill(struct Maillage,struct Maillage*,int);
 
 int ecrire_chrono(int flag,struct GestionFichiers,struct PasDeTemps,
 		  struct Maillage,struct MaillageBord,struct Variable,struct Maillage,struct ProphyRay,
-		  double*,double**,struct SDparall_ray);
+		  double*,double**,struct SDparall_ray,
+		  struct Humid,struct ConstPhyhmt,struct ConstMateriaux*,
+          struct Climcfd,struct Cfd,struct Travail,struct Travail);
 void ecrire_entete(FILE**,char*,int,double,double);
 void ecrire_flux(struct Maillage,struct Variable,struct Prophy);
 void ecrire_geom(char*,struct Maillage*,struct MaillageBord*);
-void ecrire_resu(struct GestionFichiers,struct PasDeTemps,struct Maillage,struct Variable,struct Maillage,struct ProphyRay,
-		 double*,double**,struct SDparall_ray);
+void ecrire_geom_cplcfd(char*,struct Maillage,struct MaillageCL,struct Climcfd,struct Cfd);
+void ecrire_resu(struct GestionFichiers,struct PasDeTemps,struct Maillage,struct Variable,struct Maillage,
+		 struct ProphyRay,double*,double**,struct SDparall_ray,
+		 struct Humid,struct ConstPhyhmt,struct ConstMateriaux*,
+         struct Climcfd,struct Cfd,struct Travail,struct Travail);
 void ecrire_var(FILE*,int,double*,char*,int);
-void ecrire_histo(struct PasDeTemps,struct Maillage,struct Histo,struct Variable);
-void ecrire_histo2(FILE**,char*,double,double,struct Histo,struct Maillage,struct Variable,int);
+void ecrire_histo(struct PasDeTemps,struct Maillage,struct Histo,struct Variable,struct Humid,
+		  struct ConstPhyhmt,struct ConstMateriaux*);
+void ecrire_histo2(FILE**,char*,double,double,struct Histo,struct Maillage,struct Variable,int,
+		   struct Humid,struct ConstPhyhmt,struct ConstMateriaux*);
 void ecrire_corrSR(int,struct Couple);
 void ecrire_corrRS(int,struct Couple);
 void ecrire_corrFS(int,struct Couple,struct Couple);
@@ -686,6 +695,7 @@ void user_ray(struct Maillage,double*,struct ProphyRay,
 
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV */
 void valeur_copain_parall(int,double*,double*,int,int,int*,int*,int*,double*,struct SDparall);
+double var_element_moy(int,struct Maillage,double*);
 void verif_alloue_int1d(char*,int*);
 void verif_alloue_int2d(int,char*,int**);
 void verif_alloue_double1d(char*,double*);
