@@ -1337,7 +1337,7 @@ void recale_file_fadd(FILE  **fich)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -1384,9 +1384,7 @@ void ecrire_geom_cplcfd(char *nomfich,
   for (i=0;i<maillnodes.npoin;i++)
     if (itemp[i]>-1) {
       np=itemp[i];
-      coords[0][np]=maillnodes.coord[0][i];
-      coords[1][np]=maillnodes.coord[1][i];
-      coords[2][np]=maillnodes.coord[2][i];
+      for (j=0;j<maillnodes.ndim;j++) coords[j][np]=maillnodes.coord[j][i];
     }
 
   fprintf(fich,"C*V4.0*******************************************C\n");
