@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -57,7 +57,7 @@ int nsp;
 double taille_boite,taille_seg;
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP , C. PENIGUEL                                     |
   |======================================================================|
@@ -198,7 +198,7 @@ void inifdf(struct GestionFichiers gestionfichiers,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP , C. PENIGUEL                                     |
   |======================================================================|
@@ -233,7 +233,7 @@ void regufdf(struct GestionFichiers gestionfichiers,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -600,7 +600,7 @@ void calfdf(struct Maillage maillnodray,
 
 
 /* en dessous j'ai tout change car cela ne paraissait pas bon */
-      if (maillnodray.ndim==3) xmult*=xmult;
+      if (maillnodray.ndim==3 || (maillnodray.ndim==2 && maillnodray.iaxisy)) xmult*=xmult;
 	
       for (i=0; i<nelemloc ;i++) (*diagfdf)[i]/=xmult;
 
