@@ -63,7 +63,7 @@ extern char nomcplcfdg[CHLONG];
 
 static char ch[CHLONG],motcle[CHLONG],repc[CHLONG],formule[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 
 #ifdef _SYRTHES_CFD_
