@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -55,7 +55,7 @@ extern struct Affichages affich;
 struct Performances perfo;
 extern char nomcorrr[CHLONG];
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -79,14 +79,14 @@ void init_scoupr(struct MaillageCL maillnodeus,struct Couple *scoupr,
 	{
 	  printf("\n\n %%%% ERREUR init_scoupr : Il n'y a pas de facettes ");
 	  printf("de conduction couplee avec le rayonnement ");
-	  printf("                             Voir le mot-cle 'CLIM_RAYT=   COUPLAGE_CONDUCTION'");
+	  printf("                             Voir le mot-cle 'CLIM=  COUPLAGE_RAYONNEMENT'");
 	  printf(" dans le fichier de donnees (syrthes.data)\n\n"); 
 	}
       else
 	{
 	  printf("\n\n %%%% ERREUR init_scoupr : There is no solid face coupled ");
 	  printf("with the radiation mesh ");
-	  printf("                             Check the keyword 'CLIM_RAYT=   COUPLAGE_CONDUCTION'");
+	  printf("                             Check the keyword 'CLIM=  COUPLAGE_RAYONNEMENT'");
 	  printf(" in the data file (syrthes.data)\n\n"); 
 	}
     syrthes_exit(1);
@@ -121,7 +121,7 @@ void init_scoupr(struct MaillageCL maillnodeus,struct Couple *scoupr,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -151,7 +151,7 @@ void init_rcoups(struct Maillage maillnodray,struct Couple *rcoups)
   for (i=0;i<rs;i++) rcoups->dist[i]=1.e6;
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -195,7 +195,7 @@ void corresSR(struct GestionFichiers gestionfichiers,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -310,7 +310,7 @@ void corresRS(struct GestionFichiers gestionfichiers,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -511,7 +511,7 @@ void corresSR3d(struct Maillage maillnodes,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -728,7 +728,7 @@ void corresRS3d(struct Maillage maillnodecoupl,struct Maillage maillnodray,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -933,7 +933,7 @@ void corresSR2d(struct Maillage maillnodes,struct MaillageCL maillnodeus,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1162,7 +1162,7 @@ void corresRS2d(struct Maillage maillnodecoupl,struct Maillage maillnodray,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1215,7 +1215,7 @@ void transSR(int ndim,int **nodeus,struct Couple rcoups,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1257,7 +1257,7 @@ void transRS(int ndmat,struct Couple scoupr,double *trayeq,double *erayeq)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1312,7 +1312,7 @@ void lire_corrSR(int ndim,struct Couple scoupr)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1375,7 +1375,7 @@ void lire_corrRS(int ndim,struct Couple rcoups)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1407,7 +1407,7 @@ void ecrire_corrSR(int ndim,struct Couple scoupr)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1441,7 +1441,7 @@ void ecrire_corrRS(int ndim,struct Couple rcoups)
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1554,7 +1554,7 @@ void histog_corresp(int nb, double *distance,struct SDparall_ray sdparall_ray)
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1656,7 +1656,7 @@ void transRS_parall(int ndmat,struct Couple scoupr,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1746,7 +1746,7 @@ void extract_nodecoupl_parall(struct Maillage maillnodes,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -1795,7 +1795,7 @@ void alloue_linkcondray_parall(int ndim,struct SDparall_ray *sdparall_ray)
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -2052,7 +2052,7 @@ void corresRS_parall(struct Maillage maillnodes,struct Maillage maillnodray,
 #endif
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
@@ -2139,7 +2139,7 @@ void link_condray_parall(int ndim, struct Couple rcoups,struct SDparall_ray *sdp
 #endif
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP,   C. PENIGUEL                                    |
   |======================================================================|
