@@ -116,10 +116,10 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  dhp=fmat_fdhp[nmat](betap,tauv);
 
 
-	  coeff[i] = constmateriaux[nmat].rhos*constmateriaux[nmat].cs;
-	              + tauv*constphyhmt.Cpl;
-		      + eps*pve[i]/(constphyhmt.Rv*t)*
-			(constphyhmt.Cpl+fphyhmt_fdl(constphyhmt,t)-(xlt+xhm)/t+dhp)
+	  coeff[i] = constmateriaux[nmat].rhos*constmateriaux[nmat].cs
+	              + tauv*constphyhmt.Cpl
+		      + eps*pve[i]/(constphyhmt.Rv*t)*(constphyhmt.Cpl+fphyhmt_fdl(constphyhmt,t)-(xlt+xhm)/t)
+	              - dhp*tauv
 		      + eps*constphyhmt.Cpas*(pte[i]-pve[i])/(constphyhmt.Ras*t)
 		      + betap/constphyhmt.rhol*(pte[i]-pve[i]*(xlt+xhm)/(constphyhmt.Rv*t));
 	}
@@ -144,10 +144,11 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  dhp=fmat_fdhp[nmat](betap,tauv);
 
 
-	  coeff[i] = constmateriaux[nmat].rhos*constmateriaux[nmat].cs;
-	              + tauv*constphyhmt.Cpl;
+	  coeff[i] = constmateriaux[nmat].rhos*constmateriaux[nmat].cs
+	              + tauv*constphyhmt.Cpl
 		      + eps*pve[i]/(constphyhmt.Rv*t)*
-			(constphyhmt.Cpl+fphyhmt_fdl(constphyhmt,t)-(xlt+xhm)/t+dhp)
+			(constphyhmt.Cpl+fphyhmt_fdl(constphyhmt,t)-(xlt+xhm)/t)
+	              - dhp*tauv
 		      + betap/constphyhmt.rhol*pve[i]*(1.-(xlt+xhm)/(constphyhmt.Rv*t));
 	}
       if (!ftoto) ftoto=fopen("coeff","w");
@@ -185,8 +186,8 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  dht= fmat_fdht[nmat](alphat,tauv);
 	  xhm=fmat_fhm[nmat](tauv);
 	  coeff[i] = -  alphat*pte[i]/constphyhmt.rhol
-	    - (eps*pve[i]*dht+(xlt+xhm)*(pve[i]*alphat/constphyhmt.rhol-eps))
-			/(constphyhmt.Rv*t);
+	             + dht*tauv
+	             + (xlt+xhm)*(pve[i]*alphat/constphyhmt.rhol-eps) / (constphyhmt.Rv*t);
 	}
       break;
       
@@ -205,9 +206,9 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  alphat=fmat_falpha[nmat](constphyhmt,constmateriaux[nmat],pve[i],psat,t);
 	  dht= fmat_fdht[nmat](alphat,tauv);
 	  xhm=fmat_fhm[nmat](tauv);
-	  coeff[i] = -  alphat*pve[i]/constphyhmt.rhol + eps
-	    - (eps*pve[i]*dht-(xlt+xhm)*(pve[i]*alphat/constphyhmt.rhol-eps))
-			/(constphyhmt.Rv*t);
+	  coeff[i] = -  alphat*pve[i]/constphyhmt.rhol
+	             + dht*tauv
+	             + (xlt+xhm)*(pve[i]*alphat/constphyhmt.rhol-eps) / (constphyhmt.Rv*t);
 	}
       break;
       
