@@ -56,7 +56,7 @@ extern int nbVar;
 
 static char ch[CHLONG],motcle[CHLONG],motcle2[CHLONG],repc[CHLONG],formule[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 /*|======================================================================|
   | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
