@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -36,7 +36,7 @@
 
 #include "syr_usertype.h"
 #include "syr_bd.h"
-#include "syr_hmt_bibmat.h"
+#include "syr_hmt_libmat.h"
 #include "syr_hmt_bd.h"
 #include "syr_option.h"
 #include "syr_abs.h"
@@ -59,7 +59,7 @@ extern int optim,lmst;
 extern int nbVar;
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -211,12 +211,6 @@ void hmt_resol(struct PasDeTemps *pasdetemps,
 		    sdparall);
     }
 
-  /* Impression d'information globale */
-  /* calcul masse dans l'echantillon */
-  hmt_bilan_masse(*pasdetemps,maillnodes,var_ele,
-		  humid,constphyhmt,constmateriaux,trave,
-		  sdparall);
-
   /*clipping chris  tres provisoire de la pression de vapeur */
   for (i=0;i<maillnodes.npoin;i++)
     {
@@ -234,7 +228,7 @@ void hmt_resol(struct PasDeTemps *pasdetemps,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -302,11 +296,14 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
   else
     omv(maillnodes,matr.b,variable.var[variable.adr_pv_m1],matr,perio,trav5); 
 
-/*   if (sdparall.nparts > 1)	 */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_a rang=%d nglob=%d matr.b[%d]=%25.18e\n", */
-/* 					    sdparall.rang,sdparall.npglob[i],i,matr.b[i]); */
-/*   else */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_a matr.b[%d]=%25.18e\n",i,matr.b[i]); */
+  if (affich.cond_mat) 
+	{
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_a rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_a matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
   
 /*   if (ecraddfile) add_var_in_file(maillnodes.npoin,trav5,"toto",3); */
 
@@ -331,11 +328,14 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
       else
 	omv(maillnodes,matr.b,variable.var[variable.adr_pt_m1],matr,perio,trav5);
       
-      /*   if (sdparall.nparts > 1)	 */
-      /*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_b rang=%d nglob=%d matr.b[%d]=%25.18e\n", */
-      /* 					    sdparall.rang,sdparall.npglob[i],i,matr.b[i]); */
-      /*   else */
-      /*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_b matr.b[%d]=%25.18e\n",i,matr.b[i]); */
+      if (affich.cond_mat) 
+	{
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_b rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_b matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
     }
   
   /* prise en compte (explicite) du terme :  dpv/dt */
@@ -353,12 +353,15 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
     *(matr.b+i)+=*(trav1+i) * (variable.var[variable.adr_pv_m1][i]-variable.var[variable.adr_pv_m2][i])
                             * pasdetemps.rdtts/pasdetemps.rdttsprec;
 
-/*   if (sdparall.nparts > 1)	 */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_c rang=%d nglob=%d matr.b[%d]=%25.18e\n", */
-/* 					    sdparall.rang,sdparall.npglob[i],i,matr.b[i]); */
-/*   else */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_c matr.b[%d]=%25.18e\n",i,matr.b[i]); */
-
+      if (affich.cond_mat) 
+	{
+	  
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_c rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_c matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
   
   
   /* prise en compte (explicite) du terme :  dpt/dt */
@@ -374,11 +377,15 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
 	*(matr.b+i)+=*(trav1+i) * (variable.var[variable.adr_pt_m1][i]-variable.var[variable.adr_pt_m2][i])
 	  * pasdetemps.rdtts/pasdetemps.rdttsprec;
       
-      /*   if (sdparall.nparts > 1)	 */
-      /*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_d rang=%d nglob=%d matr.b[%d]=%25.18e\n", */
-      /* 					    sdparall.rang,sdparall.npglob[i],i,matr.b[i]); */
-      /*   else */
-      /*     for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_d matr.b[%d]=%25.18e\n",i,matr.b[i]); */
+      if (affich.cond_mat) 
+	{
+	  
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_d rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_d matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
     }
 
   
@@ -511,7 +518,7 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
       if (rescon.npoin)
 	{
 	  for (i=0;i<maillnodes.npoin;i++) *(trav5+i)=0;
-	  mafclc(rescon,maillnodes,maillnodeus,variable.var[variable.adr_t_m1],trav5,trav0);
+	  hmt_mafclc_t(rescon,maillnodes,maillnodeus,variable.var[variable.adr_t_m1],trav5,trav0);
 	  
 	  if (sdparall.nparts>1) 
 	    for (j=nn=0;nn<sdparall.nparts;nn++)
@@ -534,23 +541,23 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
 	      if (SYRTHES_LANG == FR)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : rang=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc T : rang=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc T : trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	      else if (SYRTHES_LANG == EN)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : rank=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc T : rank=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc T : trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	    }
 	}
       else if (sdparall.nparts>1) 
-	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas */
+	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas bien voir isa*/
       
     }
 
@@ -674,17 +681,17 @@ void hmt_diffus_t(struct PasDeTemps pasdetemps,
     grconj_parall(maillnodes,variable.var[variable.adr_t],rescon,perio,trav,matr,epsgcs_t,nitmx_t,sdparall);
 
 
-/*   if (sdparall.nparts > 1)	 */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("rang=%d nglob=%d tmps[%d]=%25.18e\n", */
-/* 					    sdparall.rang,sdparall.npglob[i],i,tmps[i]); */
-/*   else */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("tmps[%d]=%25.18e\n",i,tmps[i]); */
+  /* if (sdparall.nparts > 1) */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Temperature rang=%d nglob=%d tmps[%d]=%25.18e\n", */
+  /* 					    sdparall.rang,sdparall.npglob[i],i,variable.var[variable.adr_t][i]); */
+  /* else */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Temperature tmps[%d]=%25.18e\n",i,variable.var[variable.adr_t][i]); */
   
 
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -747,7 +754,15 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
   else
     omv(maillnodes,matr.b,variable.var[variable.adr_t_m1],matr,perio,trav5);
 
-
+ if (affich.cond_mat) 
+	{
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_a rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_a matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
+  
   /* prise en compte (explicite) du terme : div(COEFF*grad(PT)) */
   /* ---------------------------------------------------------- */
   if (nbVar==3) /*uniquement modele a trois equations */
@@ -762,6 +777,16 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
 	omv_parall(maillnodes,matr.b,variable.var[variable.adr_pt_m1],matr,perio,trav5,sdparall);
       else
 	omv(maillnodes,matr.b,variable.var[variable.adr_pt_m1],matr,perio,trav5);
+      if (affich.cond_mat) 
+	{
+	  if (sdparall.nparts > 1)
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_b rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_b matr.b[%d]=%25.18e\n",i,matr.b[i]);
+	}
+      
+
     }
   
   /* prise en compte (explicite) du terme :  dT/dt */
@@ -775,6 +800,15 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
     *(matr.b+i)+=*(trav1+i)* (variable.var[variable.adr_t_m1][i]-variable.var[variable.adr_t_m2][i])
       * pasdetemps.rdtts/pasdetemps.rdttsprec;
 
+  if (affich.cond_mat) 
+    {
+      if (sdparall.nparts > 1)
+	for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_c rang=%d nglob=%d matr.b[%d]=%25.18e\n",
+						sdparall.rang,sdparall.npglob[i],i,matr.b[i]);
+      else
+	for (i=0;i<maillnodes.npoin;i++) printf("hmt_resol_PV_c matr.b[%d]=%25.18e\n",i,matr.b[i]);
+    }
+
 
 
   /* ************************************************************/
@@ -782,7 +816,9 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
   /* ************************************************************/
 
   azero1D(maillnodes.npoin,matr.dmat);
-  azero1D(maillnodes.nbarete,matr.xdms);
+
+  /* chris :pas sur qu'il y ait besoin de le faire la, on le fait avant la diffusion */
+  /* azero1D(maillnodes.nbarete,matr.xdms); */
 
   /* calcul de la matrice de masse */
   /* ----------------------------- */
@@ -835,7 +871,7 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
   if (maillnodeus.nelem)
     {
       hmt_mafcli_pv(hmtclimhhh,maillnodes,maillnodeus,
-		    variable,trav3,trav0);
+		    variable,constphyhmt,trav3,trav0);
       if (sdparall.nparts>1)      
 	assemb_complt(trav3,maillnodes.npoin,trav0,sdparall);
 
@@ -895,17 +931,41 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
 	assemb_complt(trav2,maillnodes.npoin,trav0,sdparall);
       
       for (i=0;i<maillnodes.npoin;i++) *(matr.dmat+i)+=*(trav2+i);
+
+
+  if (affich.cond_mat) 
+    {
+      if (SYRTHES_LANG == FR)
+	{
+	  if (sdparall.nparts > 1)	
+	    for (i=0;i<maillnodes.npoin;i++) printf("pv rang=%d nglob=%d trav2[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,trav2[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("pv trav2[%d]=%25.18e\n",i,trav2[i]);
+	}
+      else if (SYRTHES_LANG == EN)
+	{
+	  if (sdparall.nparts > 1)	
+	    for (i=0;i<maillnodes.npoin;i++) printf("pv rank=%d nglob=%d trav2matr.dmat[%d]=%25.18e\n",
+						    sdparall.rang,sdparall.npglob[i],i,trav2[i]);
+	  else
+	    for (i=0;i<maillnodes.npoin;i++) printf("pv trav2[%d]=%25.18e\n",i,trav2[i]);
+	}
     }
 
 
-  /* contribution des Resistances de contact (non implante actuellement)*/
+
+    }
+
+
+  /* contribution des Resistances de contact pour du pv (non implante actuellement et peut etre jamais)*/
   /* ------------------------------------------------------------------ */
   if (rescon.existglob)
     {
       if (rescon.npoin)
 	{
 	  for (i=0;i<maillnodes.npoin;i++) *(trav5+i)=0;
-	  mafclc(rescon,maillnodes,maillnodeus,variable.var[variable.adr_t_m1],trav5,trav0);
+	  hmt_mafclc_pv(rescon,maillnodes,maillnodeus,variable.var[variable.adr_pv_m1],trav5,trav0);
 	  
 	  if (sdparall.nparts>1) 
 	    for (j=nn=0;nn<sdparall.nparts;nn++)
@@ -916,7 +976,7 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
 	      rescon.gnonassc[i]=rescon.gassc[i]=trav5[rescon.nump[i]];
 	  
 	  /* on fait maintenant l'assemblage complementaire */
- 	  if (sdparall.nparts>1)       
+	  if (sdparall.nparts>1)       
 	    {
 	      assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); 
 	      for (j=nn=0;nn<sdparall.nparts;nn++)
@@ -928,26 +988,25 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
 	      if (SYRTHES_LANG == FR)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : rang=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc pv: rang=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc pv: trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	      else if (SYRTHES_LANG == EN)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : rank=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc pv: rank=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc pv: trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	    }
 	}
       else if (sdparall.nparts>1) 
-	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas */
-      
+	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas bien voir isa*/    
     }
-
+  
   /* second membre */
   /* ------------- */
   for (i=0;i<maillnodes.npoin;i++) *(matr.b+i) += *(trav1+i) * variable.var[variable.adr_pv_m1][i];
@@ -1010,8 +1069,6 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
       /* assemblage de la matrice sur le bord */
       matbord(maillnodes,maillnodeus,trav0,trav1);
 
-      /* ajout au second membre */
-/*       for (i=0;i<maillnodes.npoin;i++) *(matr.b+i)+=*(trav1+i); */
 
 
       if (affich.cond_mat) 
@@ -1037,6 +1094,29 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
       if (sdparall.nparts>1)      
 	assemb_complt(trav1,maillnodes.npoin,trav0,sdparall);
 
+
+      if (affich.cond_mat) 
+	{
+	  if (SYRTHES_LANG == FR)
+	    {
+	      if (sdparall.nparts > 1)	
+		for (i=0;i<maillnodes.npoin;i++) printf("rang=%d nglob=%d trav1[%d]=%25.18e\n",
+							sdparall.rang,sdparall.npglob[i],i,trav1[i]);
+	      else
+		for (i=0;i<maillnodes.npoin;i++) printf("trav1[%d]=%25.18e\n",i,trav1[i]);
+	    }
+	  else if (SYRTHES_LANG == EN)
+	    {
+	      if (sdparall.nparts > 1)	
+		for (i=0;i<maillnodes.npoin;i++) printf("rank=%d nglob=%d trav1[%d]=%25.18e\n",
+							sdparall.rang,sdparall.npglob[i],i,trav1[i]);
+	      else
+		for (i=0;i<maillnodes.npoin;i++) printf("trav1[%d]=%25.18e\n",i,trav1[i]);
+	    }
+	}
+
+      /* ajout au second membre */
+      /* for (i=0;i<maillnodes.npoin;i++) *(matr.b+i)+=*(trav1+i); */
       for (i=0;i<maillnodes.npoin;i++) *(matr.b+i)+=*(trav1+i);
 
     }
@@ -1047,22 +1127,31 @@ void hmt_diffus_pv(struct PasDeTemps pasdetemps,
     }
 
 
+
+
+  /* if (sdparall.nparts > 1) */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Avant solveur PV : rang=%d nglob=%d PV[%d]=%25.18e\n", */
+  /* 					    sdparall.rang,sdparall.npglob[i],i,variable.var[variable.adr_pv][i]); */
+  /* else */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Avant solveur PV : PV[%d]=%25.18e\n",i,variable.var[variable.adr_pv][i]); */
+
+
   if (sdparall.nparts==1)           
     grconj(maillnodes,variable.var[variable.adr_pv],rescon,perio,trav,matr,epsgcs_pv,nitmx_pv);
   else
     grconj_parall(maillnodes,variable.var[variable.adr_pv],rescon,perio,trav,matr,epsgcs_pv,nitmx_pv,sdparall);
 
 
-/*   if (sdparall.nparts > 1)	 */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("rang=%d nglob=%d tmps[%d]=%25.18e\n", */
-/* 					    sdparall.rang,sdparall.npglob[i],i,tmps[i]); */
-/*   else */
-/*     for (i=0;i<maillnodes.npoin;i++) printf("tmps[%d]=%25.18e\n",i,tmps[i]); */
+  /* if (sdparall.nparts > 1) */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Apres solveur PV : rang=%d nglob=%d PV[%d]=%25.18e\n", */
+  /* 					    sdparall.rang,sdparall.npglob[i],i,variable.var[variable.adr_pv][i]); */
+  /* else */
+  /*   for (i=0;i<maillnodes.npoin;i++) printf("Apres solveur PV : PV[%d]=%25.18e\n",i,variable.var[variable.adr_pv][i]); */
   
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1234,18 +1323,18 @@ void hmt_diffus_pt(struct PasDeTemps pasdetemps,
       if (SYRTHES_LANG == FR)
 	{
 	  if (sdparall.nparts > 1)	
-	    for (i=0;i<maillnodes.npoin;i++) printf("pv rang=%d nglob=%d matr.dmat[%d]=%25.18e\n",
+	    for (i=0;i<maillnodes.npoin;i++) printf("diag pt rang=%d nglob=%d matr.dmat[%d]=%25.18e\n",
 						    sdparall.rang,sdparall.npglob[i],i,matr.dmat[i]);
 	  else
-	    for (i=0;i<maillnodes.npoin;i++) printf("pv matr.dmat[%d]=%25.18e\n",i,matr.dmat[i]);
+	    for (i=0;i<maillnodes.npoin;i++) printf("diag pt matr.dmat[%d]=%25.18e\n",i,matr.dmat[i]);
 	}
       else if (SYRTHES_LANG == EN)
 	{
 	  if (sdparall.nparts > 1)	
-	    for (i=0;i<maillnodes.npoin;i++) printf("pv rank=%d nglob=%d matr.dmat[%d]=%25.18e\n",
+	    for (i=0;i<maillnodes.npoin;i++) printf("diag pt rank=%d nglob=%d matr.dmat[%d]=%25.18e\n",
 						    sdparall.rang,sdparall.npglob[i],i,matr.dmat[i]);
 	  else
-	    for (i=0;i<maillnodes.npoin;i++) printf("pv matr.dmat[%d]=%25.18e\n",i,matr.dmat[i]);
+	    for (i=0;i<maillnodes.npoin;i++) printf("diag pt matr.dmat[%d]=%25.18e\n",i,matr.dmat[i]);
 	}
     }
 
@@ -1267,14 +1356,14 @@ void hmt_diffus_pt(struct PasDeTemps pasdetemps,
     }
 
 
-  /* contribution des Resistances de contact */
-  /* --------------------------------------- */
+  /* contribution des Resistances de contact pour du pt (non implante actuellement et peut etre jamais)*/
+  /* ------------------------------------------------------------------ */
   if (rescon.existglob)
     {
       if (rescon.npoin)
 	{
 	  for (i=0;i<maillnodes.npoin;i++) *(trav5+i)=0;
-	  mafclc(rescon,maillnodes,maillnodeus,variable.var[variable.adr_t_m1],trav5,trav0);
+	  hmt_mafclc_pt(rescon,maillnodes,maillnodeus,variable.var[variable.adr_pt_m1],trav5,trav0);
 	  
 	  if (sdparall.nparts>1) 
 	    for (j=nn=0;nn<sdparall.nparts;nn++)
@@ -1285,7 +1374,7 @@ void hmt_diffus_pt(struct PasDeTemps pasdetemps,
 	      rescon.gnonassc[i]=rescon.gassc[i]=trav5[rescon.nump[i]];
 	  
 	  /* on fait maintenant l'assemblage complementaire */
- 	  if (sdparall.nparts>1)       
+	  if (sdparall.nparts>1)       
 	    {
 	      assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); 
 	      for (j=nn=0;nn<sdparall.nparts;nn++)
@@ -1297,23 +1386,23 @@ void hmt_diffus_pt(struct PasDeTemps pasdetemps,
 	      if (SYRTHES_LANG == FR)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : rang=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc pt : rang=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("apres mafclc pt: trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	      else if (SYRTHES_LANG == EN)
 		{
 		  if (sdparall.nparts > 1)	
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : rank=%d nglob=%d trav5[%d]=%25.18e\n",
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc pt: rank=%d nglob=%d trav5[%d]=%25.18e\n",
 							    sdparall.rang,sdparall.npglob[i],i,trav5[i]);
 		  else
-		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc : trav5[%d]=%25.18e\n",i,trav5[i]);
+		    for (i=0;i<maillnodes.npoin;i++) printf("after mafclc pt: trav5[%d]=%25.18e\n",i,trav5[i]);
 		}
 	    }
 	}
       else if (sdparall.nparts>1) 
-	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas */
+	assemb_complt(trav5,maillnodes.npoin,trav0,sdparall); /* erreur_chris : ici je ne comprends pas bien voir isa*/
       
     }
 
@@ -1431,7 +1520,7 @@ void hmt_diffus_pt(struct PasDeTemps pasdetemps,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1444,13 +1533,23 @@ void hmt_smexp_t(struct HmtClimhhh hmtclimhhh,
 {
   int i,j,nf,ng,n;
   int nel,**nodeus;
-  double t,xlt,omegamv,pv,pt,gv;
+  double omegamv,phiv,tt,pp;
+  double *t,*pv,*pt;
 
 
   for (i=0;i<maillnodeus.nelem*maillnodeus.ndmat;i++) {*(trav0+i)=0.;}
   nel=maillnodeus.nelem; 
   nodeus=maillnodeus.node;
 
+  t=variable.var[variable.adr_t_m1];
+  pv=variable.var[variable.adr_pv_m1];
+  pt=variable.var[variable.adr_pt_m1];
+
+  /* | ATTENTION  (pense bête Chris et isa pour version 4.3)
+     ! sous programme en cours il faudra verifier et ameliorer lorsque eps0=0 (metaux) |
+     | pourrait actuellement poser probleme |
+  */
+
 
   for (j=0;j<hmtclimhhh.ndmat;j++)
     for (i=0;i<hmtclimhhh.nelem;i++)
@@ -1459,38 +1558,31 @@ void hmt_smexp_t(struct HmtClimhhh hmtclimhhh,
 	/* partie explicite des coefficients d'echange sur T */
 	trav0[hmtclimhhh.numf[i]+nel*j]=hmtclimhhh.t_h[j][i]*hmtclimhhh.t_ext[j][i];
 	
+	/* partie purement explicicte */
+	nf=hmtclimhhh.numf[i]; ng=maillnodeus.node[j][nf];
 
-	/* test pour ne pas passer dans la boucle - ancienne CL de type version 3.5*/
-	if (0==1)
-	  {
-	    /* flux de chaleur (temperature et flux de vapeur) */
-	    nf=hmtclimhhh.numf[i]; ng=*(*(nodeus+j)+nf);
-	    t =variable.var[variable.adr_t_m1][ng]+tkel;    /* temperature au noeud */
-	    pv=variable.var[variable.adr_pv_m1][ng];
-	    pt=variable.var[variable.adr_pt_m1][ng];
-	    /* chris : ajuster ulterieurement en fonction du domaine avec pt le plus fort */
-	    omegamv=constphyhmt.xmv*pv/( (constphyhmt.xmv-constphyhmt.xmas)
-					 *pv+constphyhmt.xmas*pt);
-	    
-	    /* chris : Approximation pour etre coherent avec la partie implicite et la def utilisateur de h_pv */
-	    gv = hmtclimhhh.pv_h[j][i] * 
-	      ( hmtclimhhh.pv_ext[j][i]/hmtclimhhh.pt_ext[j][i]- pv/pt)*hmtclimhhh.pt_ext[j][i]
-	      + hmtclimhhh.pt_h[j][i] * omegamv * ( hmtclimhhh.pt_ext[j][i]- pt);
-	    
-	    if (gv<0)                                          /* chaleur latente */
-	      xlt=fphyhmt_fxl(constphyhmt,t);
-	    else
-	      xlt=fphyhmt_fxl(constphyhmt,hmtclimhhh.t_ext[j][i]+tkel);
-	    
-	    trav0[hmtclimhhh.numf[i]+nel*j] += xlt * gv;
-	  }
+	/* on prend la pression totale la plus forte pour le calcul de omegamv */ 
+	if (pt[ng]>hmtclimhhh.pt_ext[j][i]) pp=pt[ng];
+	else pp=hmtclimhhh.pt_ext[j][i];
 
+	omegamv=constphyhmt.xmv*pv[ng]/
+	  (constphyhmt.xmas*pp + (constphyhmt.xmv-constphyhmt.xmas)*pv[ng]);
+
+	phiv = hmtclimhhh.pv_h[j][i]* hmtclimhhh.pt_ext[j][i]
+	  * (hmtclimhhh.pv_ext[j][i]/hmtclimhhh.pt_ext[j][i] - pv[ng]/pt[ng]) 
+	  + omegamv*hmtclimhhh.pt_h[j][i]*(hmtclimhhh.pt_ext[j][i]-pt[ng]) ;
+	
+	if (phiv<0) tt=t[ng]+tkel;                 /* on prend L(Tparoi)  si flux de vapeur sortant */ 
+	else tt=hmtclimhhh.t_ext[j][i]+tkel;       /* on prend L(Text)    si flux de vapeur entrant */ 
+	
+	trav0[hmtclimhhh.numf[i]+nel*j] += fphyhmt_fxl(constphyhmt,tt)*phiv;
+	
       }
 
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1503,47 +1595,48 @@ void hmt_smexp_pv(struct HmtClimhhh hmtclimhhh,
 {
   int i,j,nf,ng,n;
   int nel,**nodeus;
-  double omegamv,pv,pt,gv;
+  double omegamv,pp;
+  double *pv,*pt;
 
+  pv=variable.var[variable.adr_pv_m1];
+  pt=variable.var[variable.adr_pt_m1];
 
   for (i=0;i<maillnodeus.nelem*maillnodeus.ndmat;i++) {*(trav0+i)=0.;}
   nel=maillnodeus.nelem; 
   nodeus=maillnodeus.node;
 
+  /* | ATTENTION  (pense bête Chris et isa pour version 4.3)
+     ! sous programme en cours il faudra verifier et ameliorer lorsque eps0=0 (metaux) |
+     | pourrait actuellement poser probleme |
+  */
+
 
   for (j=0;j<hmtclimhhh.ndmat;j++)
     for (i=0;i<hmtclimhhh.nelem;i++)
       {
 	/* flux de chaleur (temperature et flux de vapeur) */
-	nf=hmtclimhhh.numf[i]; ng=*(*(nodeus+j)+nf);
-	pt=variable.var[variable.adr_pt_m1][ng];
+	nf=hmtclimhhh.numf[i]; ng=maillnodeus.node[j][nf];
 
-	trav0[hmtclimhhh.numf[i]+nel*j]=hmtclimhhh.pv_h[j][i]*hmtclimhhh.pv_ext[j][i];
-	/* test pour ne pas passer dans la boucle - ancienne CL de type version 3.5*/
-	if (0==1)
-	  {
-	    /* partie explicite des coefficients d'echange sur PV - approximation/correction pour etre coherent
-	       avec la partie implicite*/
-	    trav0[hmtclimhhh.numf[i]+nel*j]=hmtclimhhh.pv_h[j][i]*hmtclimhhh.pv_ext[j][i]*
-	      pt/hmtclimhhh.pt_ext[j][i] ;
-	    
-	    /* voir ulterieurement le calcul de omegav en fonction de pt ou pt_ext suivant le sens ????*/
-	    omegamv=constphyhmt.xmv*pv/( (constphyhmt.xmv-constphyhmt.xmas)
-					 *pv+constphyhmt.xmas*pt);
-	    
-	    gv = + hmtclimhhh.pt_h[j][i] * omegamv * ( hmtclimhhh.pt_ext[j][i]- pt);
-	    
-	    trav0[hmtclimhhh.numf[i]+nel*j] += gv;
-	    
-	    /* rq : pression de liquide non prise en compte */
-	  }
+	trav0[hmtclimhhh.numf[i]+nel*j] = hmtclimhhh.pv_h[j][i]*hmtclimhhh.pv_ext[j][i];
+
+	/* partie a decommenter si on veut completer les CL couplees */
+	/* trav0[hmtclimhhh.numf[i]+nel*j] = hmtclimhhh.pv_h[j][i]/pt[ng]*hmtclimhhh.pv_ext[j][i]; */
+
+	/* partie purement explicite */
+	/* pp=hmtclimhhh.pt_ext[j][i];  */
+	/* if (pt[ng]>hmtclimhhh.pt_ext[j][i]) pp=pt[ng]; */
+
+	/* omegamv=constphyhmt.xmv*pv[ng]/ */
+	/*   (constphyhmt.xmas*pp+(constphyhmt.xmv-constphyhmt.xmas)*pv[ng]); */
+
+       	/* trav0[hmtclimhhh.numf[i]+nel*j] +=  omegamv*hmtclimhhh.pt_h[j][i] * (hmtclimhhh.pt_ext[j][i]-pt[ng]);  */
       }
 
 }
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1556,136 +1649,47 @@ void hmt_smexp_pt(struct HmtClimhhh hmtclimhhh,
 {
   int i,j,nf,ng,n;
   int nel,**nodeus;
-  double omegamv,pv,pt;
+  double omegamv,has,pp;
+  double *pv,*pt;
 
 
   for (i=0;i<maillnodeus.nelem*maillnodeus.ndmat;i++) {*(trav0+i)=0.;}
   nel=maillnodeus.nelem; 
   nodeus=maillnodeus.node;
 
+  pv=variable.var[variable.adr_pv_m1];
+  pt=variable.var[variable.adr_pt_m1];
 
-  /* flux de chaleur (temperature et flux de vapeur) */
+  /* | ATTENTION  (pense bête Chris et isa pour version 4.3)
+     ! sous programme en cours il faudra verifier et ameliorer lorsque eps0=0 (metaux) |
+     | pourrait actuellement poser probleme |
+  */
+
+  /* flux de chaleur (temperature et flux air sec) */
   for (j=0;j<hmtclimhhh.ndmat;j++)
     for (i=0;i<hmtclimhhh.nelem;i++)
       {
 	nf=hmtclimhhh.numf[i]; ng=*(*(nodeus+j)+nf);
-	pv=variable.var[variable.adr_pv_m1][ng];
-	pt=variable.var[variable.adr_pt_m1][ng];
 
-	/* voir ulterieurement le calcul de omegav en fonction de pt ou pt_ext suivant le sens ????*/
-	omegamv=constphyhmt.xmv*pv/( (constphyhmt.xmv-constphyhmt.xmas)
-				     *pv+constphyhmt.xmas*pt);
+	trav0[hmtclimhhh.numf[i]+nel*j] = hmtclimhhh.pt_h[j][i]*hmtclimhhh.pt_ext[j][i];
 
+
+	/* remplacer par ce qui suit si on veut les CL completes */
 	/* partie explicite des coefficients d'echange sur PT coherente avec implicite*/
-	trav0[hmtclimhhh.numf[i]+nel*j]=hmtclimhhh.pt_h[j][i]*hmtclimhhh.pt_ext[j][i];
+	/* pp=hmtclimhhh.pt_ext[j][i];  */
+	/* if (pt[ng]>hmtclimhhh.pt_ext[j][i]) pp=pt[ng]; */
+
+	/* omegamv=constphyhmt.xmv*pv[ng]/ */
+	/*   (constphyhmt.xmas*pp+(constphyhmt.xmv-constphyhmt.xmas)*pv[ng]); */
+
+	/* trav0[hmtclimhhh.numf[i]+nel*j] = (1-omegamv)*hmtclimhhh.pt_h[j][i]*hmtclimhhh.pt_ext[j][i]; */
+
+
+	/* partie purement explicite */
+	/* has=constphyhmt.xmas/constphyhmt.xmv * hmtclimhhh.pv_h[j][i]; */
+
+	/* trav0[hmtclimhhh.numf[i]+nel*j] += has/pt[ng]*hmtclimhhh.pv_ext[j][i]*(pv[ng]-hmtclimhhh.pv_ext[j][i]); */
 
-	/* test pour ne pas passer dans la boucle - ancienne CL de type version 3.5*/
-	if (0==1)
-	  {
-	    
-	    /* partie purement explicite */
-	    trav0[hmtclimhhh.numf[i]+nel*j] +=
-	      constphyhmt.xmas/constphyhmt.xmv*hmtclimhhh.pv_h[j][i]*
-	      ( -hmtclimhhh.pv_ext[j][i]/hmtclimhhh.pt_ext[j][i] + pv/pt)
-	      /* 	   + (1-omegamv)*hmtclimhhh.pt_h[j][i]*hmtclimhhh.pt_ext[j][i]; */
-	      /* Probleme chris : il y a actulleemnt incoherence facteur 1-omegamw entre implicite et explicite 
-		 je le code en explicite - ordre de grandeur par rapport a 1. ?*/
-	      + (-omegamv)*hmtclimhhh.pt_h[j][i]*hmtclimhhh.pt_ext[j][i];
-	  }
-	
       }
 
 }
-
-/*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
-  |======================================================================|
-  | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
-  |======================================================================|
-  | Calcul des masses d'eau et d'air contenu dans l'echantillon                                   |
-  |======================================================================| */
-void hmt_bilan_masse(struct PasDeTemps pasdetemps,
-		struct Maillage maillnodes,
-		double **var_ele,
-		struct Humid humid,
-		struct ConstPhyhmt constphyhmt,struct ConstMateriaux *constmateriaux,
-		struct Travail trave,
-		struct SDparall sdparall )
-{
-
-
-  int i;
-  int nmat,num;
-  double *te,*pve,*pte;
-  double t,psat,tauv,eps;
-  double bil_masse_eau,biltot_masse_eau;
-  double bil_masse_air,biltot_masse_air;
-
-
-  te=var_ele[0];
-  pve=var_ele[1];
-  pte=var_ele[2];
-
-
-  /* Calcul de la masse d'eau totale dans l'echantillon */
-  /* -------------------------------------------------- */
-  bil_masse_eau=0.;
-  for (i=0;i<maillnodes.nelem;i++)
-    {
-      nmat=humid.mat[i];
-      t=te[i]+tkel;
-      psat=fphyhmt_fpsat(t);
-      tauv=fmat_ftauv[nmat](constphyhmt,constmateriaux[nmat],pve[i],psat,t); 
-      eps=fphyhmt_feps(constphyhmt,constmateriaux[nmat],tauv);
-
-      bil_masse_eau+=(tauv+eps*pve[i]/(constphyhmt.Rv*t))*maillnodes.volume[i];
-    }
-
-  biltot_masse_eau=bil_masse_eau;
-  if (syrglob_nparts>1)
-    {
-      biltot_masse_eau=somme_double_parall(bil_masse_eau);
-    }
-
-
-  if (SYRTHES_LANG == FR)
-    {
-      printf("\n Bilan de masse \n");
-      printf(" Temps= %15.7e s -  masse_eau= %15.7e \n",pasdetemps.tempss,biltot_masse_eau);
-    }
-  else if (SYRTHES_LANG == EN)
-    {
-      printf("\n Mass Balance \n");
-      printf(" Time= %15.7e s -  mass_water= %15.7e \n",pasdetemps.tempss,biltot_masse_eau);
-	}
-
-  /* Calcul de la masse d'eau air dans l'echantillon */
-  /* -------------------------------------------------- */
-  bil_masse_air=0.;
-  for (i=0;i<maillnodes.nelem;i++)
-    {
-      nmat=humid.mat[i];
-      t=te[i]+tkel;
-      psat=fphyhmt_fpsat(t);
-      tauv=fmat_ftauv[nmat](constphyhmt,constmateriaux[nmat],pve[i],psat,t); 
-      eps=fphyhmt_feps(constphyhmt,constmateriaux[nmat],tauv);
-
-      bil_masse_air+=eps*(pte[i]-pve[i])/(constphyhmt.Ras*t)*maillnodes.volume[i];
-    }
-
-  biltot_masse_air=bil_masse_air;
-  if (syrglob_nparts>1)
-    {
-      biltot_masse_air=somme_double_parall(bil_masse_air);
-    }
-
-  if (SYRTHES_LANG == FR)
-    {
-      printf(" Temps= %15.7e s -  masse_air= %15.7e \n",pasdetemps.tempss,biltot_masse_air);
-    }
-  else if (SYRTHES_LANG == EN)
-    {
-      printf(" Time= %15.7e s -  mass_air=   %15.7e \n",pasdetemps.tempss,biltot_masse_air);
-    }
- 
-}
