@@ -57,7 +57,7 @@ struct Affichages affich;
 
 static char ch[CHLONG],motcle[CHLONG],repc[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 /*|======================================================================|
   | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
