@@ -56,7 +56,7 @@ extern int nbVar;
 
 static char ch[CHLONG],motcle[CHLONG],motcle2[CHLONG],motcle3[CHLONG],repc[CHLONG],formule[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 
 /*|======================================================================|
@@ -356,7 +356,7 @@ void decode_clim_all(struct MaillageBord *maillnodebord)
 	      for (n=0;n<nb;n++) ref[3][ilist[n]]=1;
 	    }
 	  
-	  else if (!strcmp(motcle2,"PERIODICITE_2D") || !strcmp(motcle,"PERIODICITE_3D"))
+	  else if (!strcmp(motcle2,"PERIODICITE_2D") || !strcmp(motcle2,"PERIODICITE_3D"))
 	    {   
 	      extr_motcle(motcle3,ch+id,&i3,&i4);
 	      id+=i4+1;
