@@ -817,7 +817,7 @@ void lire_suite(struct Maillage maillnodes,
 {
   FILE  *fs;
   char ch[200],ch4[4],chrien[20],chrien1[20],chrien2[20],chrien3[20];
-  int i,nbplu,typlu,nv;
+  int i,nbplu,typlu,nv,ligne_incomplete=0;
   double dt;
   double *tmps,*pv,*pt;
   if ((fs=fopen(nomsuit,"r")) == NULL)
@@ -865,6 +865,7 @@ void lire_suite(struct Maillage maillnodes,
 
 
   nv=maillnodes.npoin/6;
+  if (nv*6<maillnodes.npoin) ligne_incomplete=1;
 
   /* lecture de la temperature */
   /* ------------------------- */
@@ -872,9 +873,11 @@ void lire_suite(struct Maillage maillnodes,
   for (i=0;i<nv*6;i+=6)  fscanf(fs,"%16lf%16lf%16lf%16lf%16lf%16lf\n",
 				tmps+i,tmps+i+1,tmps+i+2,tmps+i+3,tmps+i+4,tmps+i+5);
 
-  for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",tmps+i);
-
-  for (i=0;i<maillnodes.npoin;i++) tmps[i];
+  if (ligne_incomplete>0)
+    {
+      for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",tmps+i);
+      fgets(ch,120,fs);
+    }
   
 
   /* lecture eventuelle des autres variables */
@@ -886,25 +889,30 @@ void lire_suite(struct Maillage maillnodes,
       
       pv=variable->var[variable->adr_pv];
       fgets(ch,120,fs);
-      fgets(ch,120,fs);
       for (i=0;i<nv*6;i+=6)  fscanf(fs,"%16lf%16lf%16lf%16lf%16lf%16lf\n",
 				    pv+i,pv+i+1,pv+i+2,pv+i+3,pv+i+4,pv+i+5);
       
-      for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",pv+i);
-      
-      for (i=0;i<maillnodes.npoin;i++) pv[i]; 
+      if (ligne_incomplete>0)
+	{
+	  for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",pv+i);
+	  fgets(ch,120,fs);
+	}
+ 
      
       /* lecture de PT */
       /* ------------- */
       pt=variable->var[variable->adr_pt];
       fgets(ch,120,fs);
-      fgets(ch,120,fs);
       for (i=0;i<nv*6;i+=6)  fscanf(fs,"%16lf%16lf%16lf%16lf%16lf%16lf\n",
 				    pt+i,pt+i+1,pt+i+2,pt+i+3,pt+i+4,pt+i+5);
       
-      for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",pt+i);
+      if (ligne_incomplete>0)
+	{
+	  for (i=nv*6;i<maillnodes.npoin;i++) fscanf(fs,"%16lf",pt+i);
+	  fgets(ch,120,fs);
+	}
       
-      for (i=0;i<maillnodes.npoin;i++) pt[i];      
+
     }
 
 
