@@ -777,11 +777,11 @@ void lire_limite_ray(struct Maillage maillnodray,struct ProphyRay phyray,
 		      nr=ilist[n];
 		      if (nr==-1)
 			  for (i=0;i<fimpray->nelem;i++) 
-			   {fimpray->val1[(int)(*dlist)][i]=*(dlist+1);}
+			   {fimpray->val1[(int)(*dlist)-1][i]=*(dlist+1);}
 		      else
 			for (i=0;i<fimpray->nelem;i++) 
 			  if (maillnodray.nrefe[fimpray->numf[i]]==nr) 
-			    {fimpray->val1[(int)(*dlist)][i]=*(dlist+1);}
+			    {fimpray->val1[(int)(*dlist)-1][i]=*(dlist+1);}
 		    }
 		}
 
