@@ -54,7 +54,7 @@ extern char nomdata[CHLONG];
 extern FILE *fdata;
 static char ch[CHLONG],motcle[CHLONG],repc[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 
 /*|======================================================================|
