@@ -51,7 +51,7 @@ extern FILE *fdata;
 
 static char ch[CHLONG],motcle[CHLONG],repc[CHLONG];
 static double dlist[100];
-static int ilist[100];
+static int ilist[MAX_REF];
 
 /*|======================================================================|
   | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
