@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -46,7 +46,7 @@ extern struct Performances perfo;
 extern struct Affichages affich;
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -103,7 +103,7 @@ void dupliq_maill(struct Maillage maill1,struct Maillage *maill2,int n2)
     }
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -123,7 +123,7 @@ void imprime_maillage_ref(struct Maillage maillnodes)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -149,7 +149,7 @@ void imprime_maillage(struct Maillage maillnodes)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -169,7 +169,7 @@ void imprime_connectivite(struct Maillage maillnodes)
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -194,7 +194,7 @@ void imprime_Clim(struct Clim cond)
   printf("\n\n");
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -211,7 +211,7 @@ void imprime_Climp(struct Clim cond)
   printf("\n\n");
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -229,7 +229,7 @@ void verif_alloue_int1d(char *chaine,int *pointeur)
     }
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -256,7 +256,7 @@ void verif_alloue_int2d(int idim,char *chaine,int **pointeur)
 }
     
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -274,7 +274,7 @@ void verif_alloue_double1d(char *chaine,double *pointeur)
     }
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -301,7 +301,7 @@ void verif_alloue_double2d(int idim,char *chaine,double **pointeur)
 }
     
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -347,7 +347,7 @@ void fic_bin_f__endswap
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -375,7 +375,7 @@ int verif_type_maillage(char *nomfich)
   return -1;
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -391,7 +391,7 @@ void azero1D(int ndim1,double *tab)
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -407,7 +407,7 @@ void azero2D(int ndim1, int ndim2, double **tab)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -421,7 +421,7 @@ void avaleur1D(int ndim1,double *tab,double val)
     tab[i]=val;
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -437,7 +437,7 @@ void avaleur2D(int ndim1,int ndim2,double **tab,double val)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -477,7 +477,7 @@ void verif_ray(struct Maillage maillnodray,struct ProphyRay phyray)
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -515,7 +515,7 @@ void verif_liste_ref_0N(char *motcle,int nb,int *liste)
 }
   
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -561,7 +561,7 @@ void affiche_fdf(int nelray,double *surface,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -592,13 +592,29 @@ void data_element_moy(int ne,struct Maillage maillnodes,double *var,
   else
     *z=0.;
   
-  /* temperature moyenne de l'element */
+  /* variable :  moyenne de l'element */
   for (*v=0,n=0; n<maillnodes.ndmat; n++) *v+=var[nump[n]];
   *v/=maillnodes.ndmat; 
   
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
+  |======================================================================|
+  | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
+  |======================================================================|
+  |   caracteristiques moyennes sur un element                           |
+  |======================================================================| */
+double var_element_moy(int ne,struct Maillage maillnodes,double *var)
+{
+  int n,i;
+  double vmoy;
+  
+  for (vmoy=0,n=0; n<maillnodes.ndmat; n++) vmoy+=var[maillnodes.node[n][ne]];
+  vmoy/=maillnodes.ndmat; 
+  return vmoy;
+}
+/*|======================================================================|
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -629,7 +645,7 @@ void element_center(int ne,struct Maillage maillnodes,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -666,7 +682,7 @@ double interpol_table1D(double x,int nb,double *tabX,double *tabFX)
     }
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2012 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2012 |
   |======================================================================|
   | AUTEURS  :  I. RUPP, C. PENIGUEL                                     |
   |======================================================================|
@@ -694,52 +710,43 @@ double interpol_table1D(double x,int nb,double *tabX,double *tabFX)
 double interpol_table2D(double x,double y,int nbx,int nby, double **tabXY)
 {
   int i,j,ibx,iby;
-  double al,ali,alj,d1,d2,d3,d4;
-
+  double z1,z2;
+  
   i=j=ibx=iby=-1;
   
-  if (x <= tabXY[1][0]) 
-    {i=1;ibx=0;}     
-  else if (x >= tabXY[nbx-1][0]) 
-    {i=nbx-1;ibx=0;}
-  else {
-    i=2;
-    while (x>tabXY[i][0]) i++; 
-
-    if (y <= tabXY[0][1])
-      {j=1;iby=0;}
-    else if (y >= tabXY[0][nby-1])
-      {j=nby-1; iby=0;}
-
-    while (y>tabXY[0][j]) j++; 
+  if (x <= tabXY[1][0]) {i=1;ibx=0;}     
+  else if (x >= tabXY[nbx-1][0])	{i=nbx-1;ibx=0;}
+  else {i=2; while (x>tabXY[i][0]) i++;}
   
-    if (ibx==0 && iby==0) 
-      return tabXY[i][j];
-    else if (ibx==0)
-      {
-	al=(y-tabXY[0][j-1])/(tabXY[0][j]-tabXY[0][j-1]);
-	return al*tabXY[i][j-1] + (1-al)*tabXY[i][j] ;
-      }
-    else if (iby==0)
-      {
-	al=(x-tabXY[i-1][0])/(tabXY[i][0]-tabXY[i-1][0]);
-	return al*tabXY[i-1][j] + (1-al)*tabXY[i][j] ;
-      }
-    else
-      {
-	ali=(x-tabXY[i-1][0])/(tabXY[i][0]-tabXY[i-1][0]);
-	alj=(y-tabXY[0][j-1])/(tabXY[0][j]-tabXY[0][j-1]);
-	d1=sqrt(ali*ali + alj*alj);
-	d2=sqrt(ali*ali + (1-alj)*(1-alj));
-	d3=sqrt((1-ali)*(1-ali) + alj*alj);
-	d4=sqrt((1-ali)*(1-ali) + (1-alj)*(1-alj));
-	return (d1*tabXY[i-1][j-1] + d2*tabXY[i-1][j] + d3*tabXY[i][j-1] + d4*tabXY[i][j] )/ (d1+d2+d3+d4);
-      }
-  }
-
+  if (y <= tabXY[0][1]) {j=1;iby=0;}
+  else if (y >= tabXY[0][nby-1]){j=nby-1; iby=0;}
+  else {j=2; while (y>tabXY[0][j]) j++;} 
+  
+  if (ibx==0 && iby==0) 
+    return tabXY[i][j];
+  else if (ibx==0)
+    {
+      return (tabXY[0][j]-y)/(tabXY[0][j]-tabXY[0][j-1])*tabXY[i][j-1] + \
+	(y-tabXY[0][j-1])/(tabXY[0][j]-tabXY[0][j-1])*tabXY[i][j];
+    }
+  else if (iby==0)
+    {
+      return (tabXY[i][0]-x)/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i-1][j] + \
+	(x-tabXY[i-1][0])/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i][j];
+    }
+  else
+    {
+      z1=(tabXY[i][0]-x)/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i-1][j-1] +	\
+	(x-tabXY[i-1][0])/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i][j-1];
+      z2=(tabXY[i][0]-x)/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i-1][j] +	\
+	(x-tabXY[i-1][0])/(tabXY[i][0]-tabXY[i-1][0])*tabXY[i][j];
+      return (tabXY[0][j]-y)/(tabXY[0][j]-tabXY[0][j-1])*z1 +	\
+	(y-tabXY[0][j-1])/(tabXY[0][j]-tabXY[0][j-1])*z2;
+    }
 }
+
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -769,7 +776,7 @@ void bary_tetra(double xx,double yy,double zz,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
