@@ -40,6 +40,30 @@
 # include "post_proto.h"
 
 
+/*|======================================================================|
+  | SYRTHES 4.3                2008                        COPYRIGHT EDF |
+  |======================================================================|
+  | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
+  |======================================================================|
+  |        Lecture des donnees                                           |
+  |======================================================================| */
+void ecrire_geom_entete(FILE *fich,rp_int ndim,rp_int ndiele,rp_int ndmat,
+			rp_int npoin,rp_int nelem, rp_int nelemb)
+{
+
+  fprintf(fich,"C*V4.0*******************************************C\n");
+  fprintf(fich,"C            FICHIER GEOMETRIQUE SYRTHES         C\n");
+  fprintf(fich,"C************************************************C\n");
+  fprintf(fich,"C  DIMENSION = %1d\n",ndim);
+  fprintf(fich,"C  DIMENSION DES ELTS = %1d\n",ndiele);
+  fprintf(fich,"C  NOMBRE DE NOEUDS = %12d\n",npoin);
+  fprintf(fich,"C  NOMBRE D'ELEMENTS =%12d\n",nelem);
+  fprintf(fich,"C  NOMBRE D'ELEMENTS DE BORD =%12d\n",nelemb);
+  fprintf(fich,"C  NOMBRE DE NOEUDS PAR ELEMENT = %3d\n",ndmat);
+  fprintf(fich,"C************************************************C\n");
+
+}
+
 /*|======================================================================|
   | SYRTHES 4.3                2008                        COPYRIGHT EDF |
   |======================================================================|
@@ -77,7 +101,7 @@ void ecrire_geom(char *nomfich,
   fprintf(fich,"C            FICHIER GEOMETRIQUE SYRTHES         C\n");
   fprintf(fich,"C************************************************C\n");
   fprintf(fich,"C  DIMENSION = %1d\n",maillnodes.ndim);
-  fprintf(fich,"C  DIMENSION DES ELTS = %1d\n",maillnodes.ndim);
+  fprintf(fich,"C  DIMENSION DES ELTS = %1d\n",maillnodes.ndiele);
   fprintf(fich,"C  NOMBRE DE NOEUDS = %12d\n",maillnodes.npoin);
   fprintf(fich,"C  NOMBRE D'ELEMENTS =%12d\n",maillnodes.nelem);
   fprintf(fich,"C  NOMBRE D'ELEMENTS DE BORD =%12d\n",maillnodebord.nelem);
@@ -87,26 +111,26 @@ void ecrire_geom(char *nomfich,
   fprintf(fich,"C\nC$ RUBRIQUE = NOEUDS\nC\n");
   if (maillnodes.ndim==2)
     for (i=0,c0=*coords,c1=*(coords+1);i<maillnodes.npoin;i++,c0++,c1++) 
-      fprintf(fich,"%10d%3d %14.7e %14.7e %14.7e \n", i+1,*(nref+i),*c0,*c1,z);
+      fprintf(fich,"%10d%4d %14.7e %14.7e %14.7e \n", i+1,*(nref+i),*c0,*c1,z);
   else
     for (i=0,c0=*coords,c1=*(coords+1),c2=*(coords+2);i<maillnodes.npoin;i++,c0++,c1++,c2++) 
-      fprintf(fich,"%10d%3d %14.7e %14.7e %14.7e \n",i+1,*(nref+i),*c0,*c1,*c2);
+      fprintf(fich,"%10d%4d %14.7e %14.7e %14.7e \n",i+1,*(nref+i),*c0,*c1,*c2);
 
 
 
   fprintf(fich,"C\nC$ RUBRIQUE = ELEMENTS\nC\n");
   if (maillnodes.ndmat==2)
     for (i=0,ne0=*(nodes),ne1=*(nodes+1);i<maillnodes.nelem;i++,ne0++,ne1++) 
-      fprintf(fich,"%12d%3d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1);
+      fprintf(fich,"%12d%4d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1);
 
   else if (maillnodes.ndmat==3)
     for (i=0,ne0=*(nodes),ne1=*(nodes+1),ne2=*(nodes+2);i<maillnodes.nelem;i++,ne0++,ne1++,ne2++) 
-      fprintf(fich,"%12d%3d%10d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1,*ne2+1);
+      fprintf(fich,"%12d%4d%10d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1,*ne2+1);
 
   else if (maillnodes.ndmat==4)
     for (i=0,ne0=*(nodes),ne1=*(nodes+1),ne2=*(nodes+2),ne3=*(nodes+3);
 	 i<maillnodes.nelem;i++,ne0++,ne1++,ne2++,ne3++) 
-      fprintf(fich,"%12d%3d%10d%10d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1,*ne2+1,*ne3+1);
+      fprintf(fich,"%12d%4d%10d%10d%10d%10d\n",i+1,*(nrefe+i),*ne0+1,*ne1+1,*ne2+1,*ne3+1);
 
   else 
     {
@@ -118,14 +142,14 @@ void ecrire_geom(char *nomfich,
     }
 
 
-  fprintf(fich,"C\nC$ RUBRIQUE = ELEMENTS DE BORD\nC\n");
+  if (maillnodebord.nelem>0) fprintf(fich,"C\nC$ RUBRIQUE = ELEMENTS DE BORD\nC\n");
   if (maillnodebord.ndmat==2)
     for (i=0,ne0=*(nodebord),ne1=*(nodebord+1);i<maillnodebord.nelem;i++,ne0++,ne1++) 
-      fprintf(fich,"%12d%3d%10d%10d\n",i+1,*(nrefb+i),*ne0+1,*ne1+1);
+      fprintf(fich,"%12d%4d%10d%10d\n",i+1,*(nrefb+i),*ne0+1,*ne1+1);
 
   else if (maillnodebord.ndmat==3)
     for (i=0,ne0=*(nodebord),ne1=*(nodebord+1),ne2=*(nodebord+2);i<maillnodebord.nelem;i++,ne0++,ne1++,ne2++) 
-      fprintf(fich,"%12d%3d%10d%10d%10d\n",i+1,*(nrefb+i),*ne0+1,*ne1+1,*ne2+1);
+      fprintf(fich,"%12d%4d%10d%10d%10d\n",i+1,*(nrefb+i),*ne0+1,*ne1+1,*ne2+1);
   else 
     {
       if (SYRTHES_LANG == FR)
