@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -45,7 +45,7 @@ char nomtout[200],nomtoutg[200],nomtoutr[200];
 #define max(a,b) (a>b  ? a:b)
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -62,10 +62,12 @@ main(argc,argv)
 
   char *s,ch1[200],chnum[30],*exten_geom,*exten_resu,*exten_chro,*exten_add;
   char nomg[200],nomr[200],ch[200],nomvar[30];
-  rp_int numarg,typvar;
+  char extens[6];
+
+  rp_int l,lext,numarg,typvar;
   rp_int geom=0,resu=0,chro=0,add=0,ecr_geom=1;
 
-  rp_int n,nump_min,nump_max,np,npmax,nbdt,npart=0,numpart_deb=0;
+  rp_int n,nump_min,nump_max,np,npmax=0,nbdt,npart=0,numpart_deb=0;
 
   double *var,*toutvar;
 
@@ -117,8 +119,8 @@ main(argc,argv)
 	    printf("                        -h          : mode d'emploi\n\n");
 	    printf("                        -n          : nombre de partitions a recoller\n\n");
 	    printf("                        -g          : sans ecriture du fichier geometrique complet\n\n");
-	    printf("                        -m geom.syr : nom generique des fihiers de maillage\n");
-	    printf("                        -r resu.res : nom generique des fihiers de resultats\n");
+	    printf("                        -m geom.syr : une des partitions du maillage OU nom generique des fihiers de maillage\n");
+	    printf("                        -r resu.res : resultat sur une des partitions OU nom generique des fihiers de resultats\n");
 	    printf("                        -o complet  : prefixe des fichiers resultats complets.\n\n");
 	    printf("             Exemple  :  pour post-traiter les fichiers : \n");
 	    printf("                                      geom_00004part00000.syr\n");
@@ -128,11 +130,10 @@ main(argc,argv)
 	    printf("                                      resu_00004part00000.res\n");
 	    printf("                                      resu_00004part00001.res\n");
 	    printf("                                      resu_00004part00002.res\n");
-	    printf("                                      resu_00004part00003.res\n\n");
-	    printf("                        >  a.out -n 4 -m geom.syr -r resu.res -o all\n\n");
-	    printf("                           on obtient :\n");
-	    printf("                                      all.syr   (facultatif)\n");
-	    printf("                                      all.res\n\n");
+	    printf("                                      resu_00004part00003.res\n");
+	    printf("                          et creer les fichiers complets all.syr et  all.res\n\n");
+	    printf("           a.out -n 4 -m geom.syr -r resu.res -o all\n");
+	    printf("     OU    a.out -n 4 -m geom_00004part00001.syr   -r resu_00004part00002.res -o all\n\n");
 	  }
 	else if (SYRTHES_LANG == EN)
 	  {
@@ -142,8 +143,8 @@ main(argc,argv)
 	    printf("                        -h          : help\n\n");
 	    printf("                        -n          : number of partitions to be considered\n\n");
 	    printf("                        -g          : without writing the global geometric file\n\n");
-	    printf("                        -m geom.syr : generic geometric file name\n");
-	    printf("                        -r resu.res : generic result file name\n");
+	    printf("                        -m geom.syr : one of the mesh partitions OR generic geometric file name\n");
+	    printf("                        -r resu.res : result file for one of the partitions OR generic result file name\n");
 	    printf("                        -o complet  : prefix for destination files\n\n");
 	    printf("             Example  :  to process the files : \n");
 	    printf("                                      geom_00004part00000.syr\n");
@@ -153,11 +154,10 @@ main(argc,argv)
 	    printf("                                      resu_00004part00000.res\n");
 	    printf("                                      resu_00004part00001.res\n");
 	    printf("                                      resu_00004part00002.res\n");
-	    printf("                                      resu_00004part00003.res\n\n");
-	    printf("                        >  a.out -n 4 -m geom.syr -r resu.res -o all\n\n");
-	    printf("                           files generated :\n");
-	    printf("                                      all.syr   (facultative)");
-	    printf("                                      all.res\n\n");
+	    printf("                                      resu_00004part00003.res\n");
+	    printf("                          and to create the global files all.syr et  all.res\n\n");
+	    printf("           a.out -n 4 -m geom.syr -r resu.res -o all\n");
+	    printf("     OR    a.out -n 4 -m geom_00004part00001.syr   -r resu_00004part00002.res -o all\n\n");
 	  }
 
 	exit(1);
@@ -249,17 +249,32 @@ main(argc,argv)
     if (SYRTHES_LANG == FR) printf("Le format du fichier geometrique n'est pas reconnu (.syr obligatoire) \n");
     else printf("Geometric file format unknown (.syr is required)\n");
   }
-  /* noms des fichiers sans extension */
+  /* suppression du numero de partition s'il existe */
+  l=strlen(nomgeom);  strcpy(extens,".syr\0");lext=4;
+  if (!strncmp(nomgeom+l-lext-9,"part",4) && !strncmp(nomgeom+l-lext-15,"_",1))
+    strcpy(nomgeom+l-lext-15,extens);
+
+  /* noms du fichier geometrique sans extension */
   strncpy(nomgeom_gene,nomgeom,strlen(nomgeom)-4); strcat(nomgeom_gene+strlen(nomgeom)-4,"\0"); 
 
   if (resu){
     exten_resu=strstr(nomresu,".res");
     exten_chro=strstr(nomresu,".rdt"); if (exten_chro) chro=1;
     exten_add=strstr(nomresu,".add"); if (exten_add) add=1;
-    if (!exten_resu && !exten_chro && !exten_add){
-      if (SYRTHES_LANG == FR) printf("Le format du fichier resultat n'est pas reconnu (.res ou .rdt ou .add obligatoire) \n");
-      else printf("Result file format unknown (.res or .rdt or .add required)\n");
-    }
+    if (!exten_resu && !exten_chro && !exten_add)
+      {
+	if (SYRTHES_LANG == FR) printf("Le format du fichier resultat n'est pas reconnu (.res ou .rdt ou .add obligatoire) \n");
+	else printf("Result file format unknown (.res or .rdt or .add required)\n");
+      }
+    /* suppression du numero de partition s'il existe */
+    l=strlen(nomresu);  
+    if (exten_resu) strcpy(extens,".res\0");
+    else if (exten_chro) strcpy(extens,".rdt\0");
+    else if (exten_add) strcpy(extens,".add\0");
+    lext=4;
+    if (!strncmp(nomresu+l-lext-9,"part",4) && !strncmp(nomresu+l-lext-15,"_",1))
+      strcpy(nomresu+l-lext-15,extens);
+
     /* noms des fichiers sans extension */
     strncpy(nomresu_gene,nomresu,strlen(nomresu)-4); strcat(nomresu_gene+strlen(nomresu)-4,"\0");
   }
@@ -436,6 +451,7 @@ main(argc,argv)
 	nbvar=0;
 
 	do{
+	  num_ele_deb=0;
 	  for (n=0;n<npart;n++)
 	    {	
 	      /* dans le cas ou on a teste s'il y a une var supplementaire, il y a une ligne d'entete en moins a lire */
@@ -451,12 +467,15 @@ main(argc,argv)
 		else   	       toutvar=(double*)malloc(toutnodes.npoin*sizeof(double));
 	      }
 
-	      np = sdparall[n].nbno_interne + sdparall[n].nbno_front;
+	      if (typvar==2) np = sdparall[n].nbele;
+	      else           np = sdparall[n].nbno_interne + sdparall[n].nbno_front;
+		
 	      post_lire_var(ftabresu[n],np,var);
 	      
-	      post_concat_var(np,var,toutvar,sdparall[n]);
+	      if (typvar==2) {post_concat_var2(np,var,toutvar,sdparall[n],num_ele_deb); num_ele_deb+=sdparall[n].nbele;}
+	      else            post_concat_var3(np,var,toutvar,sdparall[n]);
 	    }
-	  if (nbvar==0) ecrire_entete(ftoutr,ntsyr,rdtts,tempss);
+	  if (nbvar==0)  ecrire_entete(ftoutr,ntsyr,rdtts,tempss);
 	  if (typvar==2) ecrire_resu(ftoutr,toutnodes.nelem,toutvar,nomvar,typvar);
 	  else           ecrire_resu(ftoutr,toutnodes.npoin,toutvar,nomvar,typvar);
 	  
