@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -165,6 +165,13 @@ void pp_perio(FILE *fdata,
 					   &nbpaires,listpairesperio,&pp);
 		      free(np1); free(np2);
 		    }
+		  else
+		    {
+		      printf(" !!! ERREUR lors de la lecture des conditions aux limites\n");
+		      printf("            Le mot-cle suivant n'est pas reconnu :\n");
+		      printf("            --> CLIM=  PERIODICITE_2D %s\n",motcle);
+		      exit(1);
+		    }   
 		}
 	      else if (!strcmp(motcle,"PERIODICITE_3D")) 
 		{
@@ -197,14 +204,14 @@ void pp_perio(FILE *fdata,
 					   &nbpaires,listpairesperio,&pp);
 		      free(np1); free(np2);
 		    }
+		  else
+		    {
+		      printf(" !!! ERREUR lors de la lecture des conditions aux limites\n");
+		      printf("            Le mot-cle suivant n'est pas reconnu :\n");
+		      printf("            --> CLIM=  PERIODICITE_3D %s\n",motcle);
+		      exit(1);
+		    }   
 		}
-	      else
-		{
-		  printf(" !!! ERREUR lors de la lecture des conditions aux limites\n");
-		  printf("            Le mot-cle suivant n'est pas reconnu :\n");
-		  printf("            --> CLIM  PERIODICITE %s\n",motcle);
-		  exit(1);
-		}   
 	    }
 	  
 	}
@@ -271,7 +278,7 @@ void pp_contact(FILE *fdata,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                2008                        COPYRIGHT EDF |
+  | SYRTHES 4.3                2008                        COPYRIGHT EDF |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -413,7 +420,7 @@ void cree_liste_noeuds_periorc(struct MaillageBord maillnodebord,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                        COPYRIGHT EDF 2007|
+  | SYRTHES 4.3                                        COPYRIGHT EDF 2007|
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -497,17 +504,17 @@ void pp_cree_paires_rc(struct Maillage maillnodes,
       
 
   /* impressions de controle */
-  printf("\n Liste des paires resistance de contact\n");
-  qp=*listpairesrc;
-  while (qp){
-    printf("%12d  %12d\n",qp->num1,qp->num2);
-    qp=qp->suivant;
-  }
+  /* printf("\n Liste des paires resistance de contact\n"); */
+  /* qp=*listpairesrc; */
+  /* while (qp){ */
+  /*   printf("%12d  %12d\n",qp->num1,qp->num2); */
+  /*   qp=qp->suivant; */
+  /* } */
 
 }  
 
 /*|======================================================================|
-  | SYRTHES 4.1                                        COPYRIGHT EDF 2007|
+  | SYRTHES 4.3                                        COPYRIGHT EDF 2007|
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -603,12 +610,12 @@ void pp_cree_paires_perio(struct Maillage maillnodes,
     }
       
   /* impressions de controle */
-  printf("\n Liste des paires periodiques\n");
-  qp=*listpaires;
-  while (qp){
-    printf("%12d  %12d\n",qp->num1,qp->num2);
-    qp=qp->suivant;
-  }
+  /* printf("\n Liste des paires periodiques\n"); */
+  /* qp=*listpaires; */
+  /* while (qp){ */
+  /*   printf("%12d  %12d\n",qp->num1,qp->num2); */
+  /*   qp=qp->suivant; */
+  /* } */
 
 }  
 
