@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -508,23 +508,23 @@ void pp_cree_tables_parall(struct Maillage maillnodes,
 /*       } */
 
   /* impressions de controle */
-  if (rescontact)
-    {
-      pp=listpairesrc;
-      while(pp){
-	printf("RC %d (%d)    %d (%d)\n",pp->num1,pp->dom1,pp->num2,pp->dom2);
-	pp=pp->suivant;
-      }
-    }  
+  /* if (rescontact) */
+  /*   { */
+  /*     pp=listpairesrc; */
+  /*     while(pp){ */
+  /* 	printf("RC %d (%d)    %d (%d)\n",pp->num1,pp->dom1,pp->num2,pp->dom2); */
+  /* 	pp=pp->suivant; */
+  /*     } */
+  /*   }   */
   /* impressions de controle */
-  if (perio)
-    {
-      pp=listpairesperio;
-      while(pp){
-	printf("PER %d (%d)    %d (%d)\n",pp->num1,pp->dom1,pp->num2,pp->dom2);
-	pp=pp->suivant;
-      }
-    }  
+  /* if (perio) */
+  /*   { */
+  /*     pp=listpairesperio; */
+  /*     while(pp){ */
+  /* 	printf("PER %d (%d)    %d (%d)\n",pp->num1,pp->dom1,pp->num2,pp->dom2); */
+  /* 	pp=pp->suivant; */
+  /*     } */
+  /*   }   */
 
   /* construction des listes ordonnees pour les resistances de contact */
   /* RCRCRCRCRC------------------------------------------------------- */
@@ -831,18 +831,18 @@ void pp_cree_liste_ordo(rp_int npart,struct NodeRCP ****tcommunx,rp_int ***nbcom
 
  
   /* impression de controle */
-  for (i=0;i<npart;i++)
-    for (j=0;j<npart;j++)
-      {
-	printf("paires partition %d %d :",i,j);
-	qrc=(*tcommunx)[i][j];
-	while (qrc)
-	  {
-	    printf(" (%d,%d)",qrc->num1,qrc->num2);
-	    qrc=qrc->suivant;
-	  }
-	printf("\n");
-      }
+  /* for (i=0;i<npart;i++) */
+  /*   for (j=0;j<npart;j++) */
+  /*     { */
+  /* 	printf("paires partition %d %d :",i,j); */
+  /* 	qrc=(*tcommunx)[i][j]; */
+  /* 	while (qrc) */
+  /* 	  { */
+  /* 	    printf(" (%d,%d)",qrc->num1,qrc->num2); */
+  /* 	    qrc=qrc->suivant; */
+  /* 	  } */
+  /* 	printf("\n"); */
+  /*     } */
 }
 
 
