@@ -200,7 +200,7 @@ int lire_ideas (struct typ_maillage *maillage)
 				 (node111[2]+ne111),(node111[3]+ne111));
 			  ne111++;
 			}
-		      else if (n2==91) /* triangles */
+		      else if (n2==91 || n2==41  ) /* triangles */
 			{
 			  if (ne91>finnod91-1)
 			    {
