@@ -147,7 +147,7 @@ int ouvrir_med(struct typ_maillage *maillage, /* INOUT structure de maillage */
 int fermer_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
    /* fermeture du fichier .med */ 
-   if (MEDfileClose((int) (*maillage).fichier_ext) < 0) {
+   if (MEDfileClose((med_idt) (*maillage).fichier_ext) < 0) {
      printf("ERROR : unable to close the file .med\n");
      return 1;
    }
@@ -159,7 +159,7 @@ int fermer_med(struct typ_maillage *maillage) {
 int lire_entete_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 /* lecture des informations sur le maillage */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
@@ -316,7 +316,7 @@ int lire_entete_med(struct typ_maillage *maillage) {
 			       &transformation);
   
   if ( (segmentP2>0 || triangleP2>0 || tetraedreP2>0) && ((*maillage).version_syr == 4) ) {
-    printf("ERROR :  quadratic elements found - This is not allowed with SYRTHES 4.0, Stop.\n");
+    printf("ERROR :  quadratic elements found - This is not allowed with SYRTHES, Stop.\n");
     return 1;
   }
 
@@ -389,7 +389,7 @@ int ecrire_correspondance_syr_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 
 /* lecture des informations sur le maillage */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
@@ -534,7 +534,7 @@ int ecrire_correspondance_syr_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 int lire_coord_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
@@ -647,7 +647,7 @@ int lire_noeuds_colores_med(struct typ_maillage *maillage) {
 /* allocation et initialisation du tableau des couleurs des noeuds */
 
   int i; /* indice de boucle */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   char maa[MED_NAME_SIZE+1];
   char desc[MED_COMMENT_SIZE+1];
   med_mesh_type type;
@@ -723,7 +723,7 @@ int lire_noeuds_colores_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 int lire_elem_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
@@ -905,7 +905,7 @@ int lire_zones_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 
   int i ; /* indice de boucle */
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
@@ -1027,7 +1027,7 @@ int lire_cl_med(struct typ_maillage *maillage) {
 /* ******************************************************************* */
 /* conditions limites */
 
-  med_idt fid = (int) (*maillage).fichier_ext;
+  med_idt fid = (med_idt) (*maillage).fichier_ext;
   /* la dimension du maillage */
   med_int mdim;
   /* nom du maillage de longueur maxi MED_NAME_SIZE */
