@@ -108,12 +108,12 @@ int lire_coord_msh(struct typ_maillage *maillage) {
     /* allocations et verifications */
     ((*maillage).xcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).xcoord == NULL) {
-      printf("ERROR : allocation error for the x coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error for the x coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }
     ((*maillage).ycoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).ycoord == NULL) {
-      printf("ERROR : allocation error for the y coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error for the y coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     numnoeud_moinsun = 0;
@@ -127,17 +127,17 @@ int lire_coord_msh(struct typ_maillage *maillage) {
     /* allocations et verifications */
     ((*maillage).xcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).xcoord == NULL) {
-      printf("ERROR : allocation error for the x coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error for the x coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }
     ((*maillage).ycoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).ycoord == NULL) {
-      printf("ERROR : allocation error for the y coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error for the y coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     ((*maillage).zcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).zcoord == NULL) {
-      printf("ERROR : allocation error for the z coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error for the z coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     for (numnoeud_moinsun = 0; numnoeud_moinsun < (*maillage).nbnoeuds ; numnoeud_moinsun++) {
@@ -171,7 +171,7 @@ int lire_noeuds_colores_msh(struct typ_maillage *maillage) {
   /* allocation */
   ((*maillage).coul_noeud) = (int *) malloc (sizeof(int) * ((*maillage).nbnoeuds));
   if ((*maillage).coul_noeud == NULL) {
-    printf("ERROR : allocation error for nodes color, needed size : %i \n", sizeof(int) * ((*maillage).nbnoeuds));
+    printf("ERROR : allocation error for nodes color, needed size : %zu \n", sizeof(int) * ((*maillage).nbnoeuds));
     return 1;
   }   
   /* initialisation a zero */
@@ -243,12 +243,12 @@ int lire_elem_msh(struct typ_maillage *maillage) {
   coul_elem_triangle = (int *) malloc (sizeof(int ) * nbelemtotal);
   coul_elem_segment = (int *) malloc (sizeof(int ) * nbelemtotal);
   if (elem_tetraedre == NULL || elem_triangle == NULL || elem_segment == NULL) {
-    printf("ERROR : allocation error (lecture_msh), needed size for each elem_ : %i \n", sizeof(int *) * (nbelemtotal));
+    printf("ERROR : allocation error (lecture_msh), needed size for each elem_ : %zu \n", sizeof(int *) * (nbelemtotal));
     return 1;
   }
   /* les allocations plus basses de ces tableaux seront faites en fonction des elements trouves (elements de bord ou non) */
   if (coul_elem_tetraedre == NULL || coul_elem_triangle == NULL || coul_elem_segment == NULL) {
-    printf("ERROR : allocation error for the elements color, needed size : %i \n", sizeof(int) * (nbelemtotal));
+    printf("ERROR : allocation error for the elements color, needed size : %zu \n", sizeof(int) * (nbelemtotal));
     return 1;
   }
   
