@@ -172,12 +172,12 @@ int lire_coord_neu(struct typ_maillage *maillage) {
     /* allocations et verifications */
     ((*maillage).xcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).xcoord == NULL) {
-      printf("ERROR : allocation error, x coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error, x coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }
     ((*maillage).ycoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).ycoord == NULL) {
-      printf("ERROR : allocation error, y coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error, y coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     numnoeud_moinsun = 0;
@@ -191,17 +191,17 @@ int lire_coord_neu(struct typ_maillage *maillage) {
     /* allocations et verifications */
     ((*maillage).xcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).xcoord == NULL) {
-      printf("ERROR : allocation error, x coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error, x coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }
     ((*maillage).ycoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).ycoord == NULL) {
-      printf("ERROR : allocation error, y coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error, y coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     ((*maillage).zcoord) = (double *) malloc (sizeof(double) * ((*maillage).nbnoeuds));
     if ((*maillage).zcoord == NULL) {
-      printf("ERROR : allocation error, z coordinate, needed size : %i \n", sizeof(double) * ((*maillage).nbnoeuds));
+      printf("ERROR : allocation error, z coordinate, needed size : %zu \n", sizeof(double) * ((*maillage).nbnoeuds));
       return 1;
     }   
     for (numnoeud_moinsun = 0; numnoeud_moinsun < (*maillage).nbnoeuds ; numnoeud_moinsun++) {
@@ -236,7 +236,7 @@ int lire_noeuds_colores_neu(struct typ_maillage *maillage) {
   /* allocation */
   ((*maillage).coul_noeud) = (int *) malloc (sizeof(int) * ((*maillage).nbnoeuds));
   if ((*maillage).coul_noeud == NULL) {
-    printf("ERROR : allocation error for the node color table, needed size : %i \n", sizeof(int) * ((*maillage).nbnoeuds));
+    printf("ERROR : allocation error for the node color table, needed size : %zu \n", sizeof(int) * ((*maillage).nbnoeuds));
     return 1;
   }   
   /* initialisation a zero */
@@ -283,7 +283,7 @@ int lire_elem_neu(struct typ_maillage *maillage) {
   /* allocation et verification */
   (*maillage).liste_elem = (int **) malloc (sizeof(int *) * ((*maillage).nbelem));
   if ((*maillage).liste_elem == NULL) {
-    printf("ERROR : allocation error for the connectivity, needed size : %i \n", sizeof(int *) * ((*maillage).nbelem));
+    printf("ERROR : allocation error for the connectivity, needed size : %zu \n", sizeof(int *) * ((*maillage).nbelem));
     return 1;
   }
 
@@ -551,7 +551,7 @@ int lire_zones_neu(struct typ_maillage *maillage) {
   /* allocation du tableau des couleurs d'elements et verification */
   (*maillage).coul_elem = (int *) malloc (sizeof(int) * ((*maillage).nbelem));
   if ((*maillage).liste_elem == NULL) {
-    printf("ERROR : allocation error for the elements color table, needed size : %i \n", sizeof(int) * ((*maillage).nbelem));
+    printf("ERROR : allocation error for the elements color table, needed size : %zu \n", sizeof(int) * ((*maillage).nbelem));
     return 1;
   }
   /* initialisation a 0 des couleurs d'elements */
@@ -678,7 +678,7 @@ int lire_cl_neu(struct typ_maillage *maillage) {
     /* allocation du tableau du nombre d'elements par condition limite */
     nbelem_de_la_cl = (int *) malloc (sizeof(int) * ((*maillage).nbcl));
     if (nbelem_de_la_cl == NULL) {
-      printf("ERROR : allocation error for nbelem_de_la_cl, needed size : %i \n", sizeof(int) * ((*maillage).nbcl));
+      printf("ERROR : allocation error for nbelem_de_la_cl, needed size : %zu \n", sizeof(int) * ((*maillage).nbcl));
       return 1;
     }
     for (i=0;i<(*maillage).nbcl;i++) nbelem_de_la_cl[i] = 0;
@@ -687,7 +687,7 @@ int lire_cl_neu(struct typ_maillage *maillage) {
     /* allocation du tableau des listes des elements de bord : une partie ne sert pas si parmi les conditions il y a des conditions noeuds */
     elembord = (int ***) malloc (sizeof(int **) * ((*maillage).nbcl));
     if (elembord == NULL) {
-      printf("ERROR : allocation error for the boundary elements, needed size : %i \n", sizeof(int **) * ((*maillage).nbcl));
+      printf("ERROR : allocation error for the boundary elements, needed size : %zu \n", sizeof(int **) * ((*maillage).nbcl));
       return 1;
     }
     
@@ -825,12 +825,12 @@ int lire_cl_neu(struct typ_maillage *maillage) {
     (*maillage).nbelem_de_bord = numelembord;
     (*maillage).liste_elembord = (int **) malloc (sizeof(int *) * numelembord);
     if ((*maillage).liste_elembord == NULL) {
-      printf("ERROR : allocation error for the boundary elements list, needed size : %i \n", sizeof(int *) * numelembord);
+      printf("ERROR : allocation error for the boundary elements list, needed size : %zu \n", sizeof(int *) * numelembord);
       return 1;
     }
     (*maillage).coul_elembord = (int *) malloc (sizeof(int) * numelembord);
     if ((*maillage).coul_elembord == NULL) {
-      printf("ERROR : allocation error for the boundary elements color, needed size : %i \n", sizeof(int) * numelembord);
+      printf("ERROR : allocation error for the boundary elements color, needed size : %zu \n", sizeof(int) * numelembord);
       return 1;
     }
     
