@@ -11,6 +11,8 @@
 #define POST_TYPEWIDTH 32
 #define SYRTHES_LANG 0
 
+#define MAX_REF 1000
+
 /* ------------------------------------------- */
 
 #if POST_TYPEWIDTH == 32
@@ -547,7 +549,6 @@ void geom_syr_node(rp_int ndim,rp_int nelem,rp_int nbno,rp_int **node,rp_int *nr
   rp_int i,j,n;
     char ch[90];
 
-
     /* connectivite maillage SYRTHES */
     fgets(ch,90,fsyrg);
     fgets(ch,90,fsyrg);
@@ -628,7 +629,6 @@ void geom_syr_node_bord(rp_int ndim,rp_int nelembord,rp_int **nodebord,rp_int *n
 	nodebord[j][i]--;
 }
 
-
 /*|======================================================================|
   | SYRTHES - Utilitaires      JUIL 95                                   |
   |======================================================================|
@@ -858,7 +858,7 @@ void geom_ens_node_ascii(rp_int ndim,rp_int ndiele,rp_int nelem,rp_int nbno,rp_i
 {
   rp_int i,j,n,numpart;
   char ch[80];
-  rp_int iref[100];
+  rp_int iref[MAX_REF];
 
 
   /* ecriture des elements */
@@ -898,14 +898,14 @@ void geom_ens_node_ascii(rp_int ndim,rp_int ndiele,rp_int nelem,rp_int nbno,rp_i
   /* ---------------------------------------------- */
   if (noVol==0)
     {
-      for (i=0;i<100;i++) iref[i]=0;
+      for (i=0;i<MAX_REF;i++) iref[i]=0;
       
       /* on compte combien il y d'elements de chaque couleur */
       for (n=0;n<nelem;n++)
 	if (nrefe[n]>0) iref[nrefe[n]]++;
       
       printf("\n");
-      for (i=0;i<100;i++) 
+      for (i=0;i<MAX_REF;i++) 
 	if (iref[i]>0) 
 	  {
 	    printf("   Volume %2d : number of cells = %8d\n",i,iref[i]);
@@ -960,7 +960,7 @@ void geom_ens_node_bin(rp_int ndim,rp_int ndiele,rp_int nelem,rp_int nbno,rp_int
 
 {
   rp_int i,j,nn,n,nl,npoinloc,numpart;
-  rp_int iref[100],*no1d,*numloc,*numglob;
+  rp_int iref[MAX_REF],*no1d,*numloc,*numglob;
   char ch[80];
   float *coosp;
 
@@ -1012,7 +1012,7 @@ void geom_ens_node_bin(rp_int ndim,rp_int ndiele,rp_int nelem,rp_int nbno,rp_int
   /* creation de part pour les proprietes physiques */
   /* ---------------------------------------------- */
 
-  for (n=0;n<100;n++) iref[n]=0;
+  for (n=0;n<MAX_REF;n++) iref[n]=0;
 
   numloc=(rp_int*)malloc(npoin*sizeof(rp_int));
 
@@ -1020,12 +1020,12 @@ void geom_ens_node_bin(rp_int ndim,rp_int ndiele,rp_int nelem,rp_int nbno,rp_int
   for (n=0;n<nelem;n++)
     if (nrefe[n]>0) iref[nrefe[n]]++;
   
-  for (n=0;n<100;n++) 
+  for (n=0;n<MAX_REF;n++) 
     if (iref[n]>0) printf("   Number of elements of volume %2d = %8d\n",n,iref[n]);
   
 
   /* pour chaque part.... */
-  for (i=1;i<100;i++)
+  for (i=1;i<MAX_REF;i++)
     if (iref[i]>0)
       {
 	for (n=0;n<npoin;n++) numloc[n]=-1;
@@ -1144,7 +1144,7 @@ void geom_ens_node_bord_ascii(rp_int ndim,rp_int ndiele,
 			      rp_int npartcree)
 {
   rp_int i,j,n,nelemd,nbsselt,numpart;
-  rp_int iref[100];
+  rp_int iref[MAX_REF];
 
 
   numpart=npartcree;
@@ -1167,20 +1167,20 @@ void geom_ens_node_bord_ascii(rp_int ndim,rp_int ndiele,
     }
   
   /* creation d'une part par numero de reference */
-  for (n=0;n<100;n++) iref[n]=0;
+  for (n=0;n<MAX_REF;n++) iref[n]=0;
   
   /* on compte combien il y d'elements de chaque couleur */
   for (n=0;n<nelembord;n++)
     if (nrefebord[n]>0) iref[nrefebord[n]]++;
   
   printf("\n");
-  for (n=0;n<100;n++) 
+  for (n=0;n<MAX_REF;n++) 
     if (iref[n]>0) 
       printf("   Surface %2d : number of border elements = %8d\n",n,iref[n]);
   
   
   
-  for (i=0;i<100;i++)
+  for (i=0;i<MAX_REF;i++)
     if (iref[i]>0)
       {
 	if (ndiele==2) /* alors elements de bord sont des poutres */
@@ -1218,7 +1218,7 @@ void geom_ens_node_bord_bin(rp_int ndim,rp_int ndiele,
 			    rp_int npoin,double **coord)
 {
   rp_int i,j,n,nl,npoinloc,numpart,nn;
-  rp_int iref[100],*numloc,*numglob,*no1d;
+  rp_int iref[MAX_REF],*numloc,*numglob,*no1d;
   float *coosp;
   char ch[80];
 
@@ -1230,13 +1230,13 @@ void geom_ens_node_bord_bin(rp_int ndim,rp_int ndiele,
 
 
   numloc=(rp_int*)malloc(npoin*sizeof(rp_int));
-  for (n=0;n<100;n++) iref[n]=0;
+  for (n=0;n<MAX_REF;n++) iref[n]=0;
       
   /* on compte combien il y de faces chaque couleur */
   for (n=0;n<nelembord;n++)
     if (nrefebord[n]>0) iref[nrefebord[n]]++;
   
-  for (i=1;i<100;i++)
+  for (i=1;i<MAX_REF;i++)
     if (iref[i]>0)
       {
 	printf("   Number of faces with reference %2d = %10d\n",i,iref[i]);
@@ -1344,7 +1344,7 @@ void ecrit_var_ensight_ascii(FILE *fvar,rp_int discr,rp_int nbre,rp_int nbno,
 			     rp_int nelem,rp_int *nrefe)
 {
   rp_int nbl,i,j,n,ne,nn,numpart;
-  rp_int iref[100],*itrav;
+  rp_int iref[MAX_REF],*itrav;
   
   if (discr==3)
     {
@@ -1385,7 +1385,7 @@ void ecrit_var_ensight_ascii(FILE *fvar,rp_int discr,rp_int nbre,rp_int nbno,
   /* si c'est une variable sur les elements, il faut la reecrire pour chaque sous-part de volume */
   if (discr==2 && noVol==0)
     {
-      for (n=0;n<100;n++) iref[n]=0;
+      for (n=0;n<MAX_REF;n++) iref[n]=0;
       
       if (noPlain==1) numpart=1; 
       else numpart=2;
@@ -1396,7 +1396,7 @@ void ecrit_var_ensight_ascii(FILE *fvar,rp_int discr,rp_int nbre,rp_int nbno,
       for (n=0;n<nelem;n++)
 	if (nrefe[n]>0) iref[nrefe[n]]++;
       
-      for (n=0;n<100;n++) 
+      for (n=0;n<MAX_REF;n++) 
 	if (iref[n]>0) 
 	  {
 	    printf("               Volume %2d : number of cells = %8d\n",n,iref[n]);
